@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -51,7 +51,8 @@ class CControllerMediatypeCreate extends CController {
 			'attempt_interval' =>		'db media_type.attempt_interval',
 			'description' =>			'db media_type.description',
 			'form_refresh' =>			'int32',
-			'content_type' =>			'db media_type.content_type|in '.SMTP_MESSAGE_FORMAT_PLAIN_TEXT.','.SMTP_MESSAGE_FORMAT_HTML
+			'content_type' =>			'db media_type.content_type|in '.SMTP_MESSAGE_FORMAT_PLAIN_TEXT.','.SMTP_MESSAGE_FORMAT_HTML,
+			'message_templates' =>		'array'
 		];
 
 		$ret = $this->validateInput($fields);
@@ -72,7 +73,7 @@ class CControllerMediatypeCreate extends CController {
 				case self::VALIDATION_ERROR:
 					$response = new CControllerResponseRedirect('zabbix.php?action=mediatype.edit');
 					$response->setFormData($this->getInputAll());
-					$response->setMessageError(_('Cannot add media type'));
+					CMessageHelper::setErrorTitle(_('Cannot add media type'));
 					$this->setResponse($response);
 					break;
 
@@ -86,7 +87,7 @@ class CControllerMediatypeCreate extends CController {
 	}
 
 	protected function checkPermissions() {
-		return ($this->getUserType() == USER_TYPE_SUPER_ADMIN);
+		return $this->checkAccess(CRoleHelper::UI_ADMINISTRATION_MEDIA_TYPES);
 	}
 
 	protected function doAction() {
@@ -95,6 +96,7 @@ class CControllerMediatypeCreate extends CController {
 		$this->getInputs($mediatype, ['type', 'name', 'status', 'maxsessions', 'maxattempts', 'attempt_interval',
 			'description'
 		]);
+		$mediatype['message_templates'] = $this->getInput('message_templates', []);
 
 		switch ($mediatype['type']) {
 			case MEDIA_TYPE_EMAIL:
@@ -148,13 +150,19 @@ class CControllerMediatypeCreate extends CController {
 		$result = API::Mediatype()->create($mediatype);
 
 		if ($result) {
-			$response = new CControllerResponseRedirect('zabbix.php?action=mediatype.list&uncheck=1');
-			$response->setMessageOk(_('Media type added'));
+			$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
+				->setArgument('action', 'mediatype.list')
+				->setArgument('page', CPagerHelper::loadPage('mediatype.list', null))
+			);
+			$response->setFormData(['uncheck' => '1']);
+			CMessageHelper::setSuccessTitle(_('Media type added'));
 		}
 		else {
-			$response = new CControllerResponseRedirect('zabbix.php?action=mediatype.edit');
+			$response = new CControllerResponseRedirect(
+				(new CUrl('zabbix.php'))->setArgument('action', 'mediatype.edit')
+			);
 			$response->setFormData($this->getInputAll());
-			$response->setMessageError(_('Cannot add media type'));
+			CMessageHelper::setErrorTitle(_('Cannot add media type'));
 		}
 		$this->setResponse($response);
 	}
