@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -394,7 +394,7 @@ class CControllerPopupGeneric extends CController {
 				]
 			],
 			'api_methods' => [
-				'title' => _('Api methods'),
+				'title' => _('API methods'),
 				'min_user_type' => USER_TYPE_SUPER_ADMIN,
 				'allowed_src_fields' => 'name',
 				'form' => [
@@ -404,7 +404,7 @@ class CControllerPopupGeneric extends CController {
 				'table_columns' => [
 					_('Name')
 				]
-			],
+			]
 		];
 	}
 
