@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ class CControllerProxyHostEnable extends CController {
 	}
 
 	protected function checkPermissions() {
-		if ($this->getUserType() != USER_TYPE_SUPER_ADMIN) {
+		if (!$this->checkAccess(CRoleHelper::UI_ADMINISTRATION_PROXIES)) {
 			return false;
 		}
 
@@ -67,13 +67,17 @@ class CControllerProxyHostEnable extends CController {
 
 		$updated = count($hosts);
 
-		$response = new CControllerResponseRedirect('zabbix.php?action=proxy.list&uncheck=1');
+		$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
+			->setArgument('action', 'proxy.list')
+			->setArgument('page', CPagerHelper::loadPage('proxy.list', null))
+		);
 
 		if ($result) {
-			$response->setMessageOk(_n('Host enabled', 'Hosts enabled', $updated));
+			$response->setFormData(['uncheck' => '1']);
+			CMessageHelper::setSuccessTitle(_n('Host enabled', 'Hosts enabled', $updated));
 		}
 		else {
-			$response->setMessageError(_n('Cannot enable host', 'Cannot enable hosts', $updated));
+			CMessageHelper::setErrorTitle(_n('Cannot enable host', 'Cannot enable hosts', $updated));
 		}
 		$this->setResponse($response);
 	}
