@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -75,11 +75,14 @@ class CControllerWidgetFavScreensView extends CControllerWidget {
 		CArrayHelper::sort($screens, ['label']);
 
 		$this->setResponse(new CControllerResponseData([
-			'name' => $this->getInput('name', CWidgetConfig::getKnownWidgetTypes()[WIDGET_FAV_SCREENS]),
+			'name' => $this->getInput('name',
+				CWidgetConfig::getKnownWidgetTypes($this->getContext())[WIDGET_FAV_SCREENS]
+			),
 			'screens' => $screens,
 			'user' => [
 				'debug_mode' => $this->getDebugMode()
-			]
+			],
+			'allowed_ui_screens' => $this->checkAccess(CRoleHelper::UI_MONITORING_SCREENS)
 		]));
 	}
 }
