@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -103,7 +103,9 @@ if ($web_layout_mode == ZBX_LAYOUT_NORMAL) {
 					->setWidth(ZBX_TEXTAREA_FILTER_STANDARD_WIDTH)
 				)
 				->addRow(_('Show items without data'),
-					(new CCheckBox('filter_show_without_data'))->setChecked($data['filter']['show_without_data'] == 1)
+					(new CCheckBox('filter_show_without_data'))
+						->setChecked($data['filter']['show_without_data'] == 1)
+						->setAttribute('disabled', $data['filter']['hostids'] ? null : 'disabled')
 				)
 				->addRow(_('Show details'),
 					(new CCheckBox('filter_show_details'))->setChecked($data['filter']['show_details'] == 1)
@@ -113,8 +115,8 @@ if ($web_layout_mode == ZBX_LAYOUT_NORMAL) {
 }
 
 $widget->addItem(new CPartial('monitoring.latest.view.html', array_intersect_key($data, array_flip(['filter',
-	'sort_field', 'sort_order', 'view_curl', 'rows', 'hosts', 'applications', 'applications_size', 'items', 'history',
-	'paging'
+	'sort_field', 'sort_order', 'view_curl', 'paging', 'rows', 'hosts', 'applications', 'applications_size',
+	'applications_index', 'items', 'history', 'collapsed_index', 'collapsed_all', 'config'
 ]))));
 
 $widget->show();
