@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2018 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,22 +19,34 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 // indicator of sort field
 $sort_div = (new CSpan())->addClass(ZBX_STYLE_ARROW_UP);
 
-$table = (new CTableInfo())->setHeader([[_('Host group'), $sort_div], _('Ok'), _('Failed'), _('Unknown')]);
+$table = (new CTableInfo())
+	->setHeader([[_('Host group'), $sort_div], _('Ok'), _('Failed'), _('Unknown')])
+	->setHeadingColumn(0);
 
-$url = (new CUrl('zabbix.php'))
-	->setArgument('action', 'web.view')
-	->setArgument('groupid', '')
-	->setArgument('hostid', '0')
-	->setArgument('fullscreen', $data['fullscreen'] ? '1' : null);
+$url = $data['allowed_ui_hosts']
+	? (new CUrl('zabbix.php'))
+		->setArgument('action', 'web.view')
+		->setArgument('filter_set', '1')
+	: null;
 
 foreach ($data['groups'] as $group) {
-	$url->setArgument('groupid', $group['groupid']);
+	if ($url !== null) {
+		$url->setArgument('filter_groupids', [$group['groupid']]);
+		$group_name = new CLink($group['name'], $url->getUrl());
+	}
+	else {
+		$group_name = $group['name'];
+	}
 
 	$table->addRow([
-		new CLink($group['name'], $url->getUrl()),
+		$group_name,
 		($group['ok'] != 0) ? (new CSpan($group['ok']))->addClass(ZBX_STYLE_GREEN) : '',
 		($group['failed'] != 0) ? (new CSpan($group['failed']))->addClass(ZBX_STYLE_RED) : '',
 		($group['unknown'] != 0) ? (new CSpan($group['unknown']))->addClass(ZBX_STYLE_GREY) : ''
@@ -43,8 +55,7 @@ foreach ($data['groups'] as $group) {
 
 $output = [
 	'header' => $data['name'],
-	'body' => $table->toString(),
-	'footer' => (new CList([_s('Updated: %s', zbx_date2str(TIME_FORMAT_SECONDS))]))->toString()
+	'body' => $table->toString()
 ];
 
 if (($messages = getMessages()) !== null) {
@@ -56,4 +67,4 @@ if ($data['user']['debug_mode'] == GROUP_DEBUG_MODE_ENABLED) {
 	$output['debug'] = CProfiler::getInstance()->make()->toString();
 }
 
-echo (new CJson())->encode($output);
+echo json_encode($output);
