@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -26,7 +26,9 @@ require_once dirname(__FILE__).'/include/forms.inc.php';
 
 $page['title'] = _('Configuration of discovery rules');
 $page['file'] = 'host_discovery.php';
-$page['scripts'] = ['class.cviewswitcher.js', 'multilineinput.js', 'multiselect.js', 'items.js', 'textareaflexible.js'];
+$page['scripts'] = ['class.cviewswitcher.js', 'multilineinput.js', 'multiselect.js', 'items.js', 'textareaflexible.js',
+	'class.tab-indicators.js'
+];
 
 require_once dirname(__FILE__).'/include/page_header.php';
 
@@ -42,7 +44,7 @@ $evalTypes = [
 
 // VAR	TYPE	OPTIONAL	FLAGS	VALIDATION	EXCEPTION
 $fields = [
-	'hostid' =>					[T_ZBX_INT, O_OPT, P_SYS,	DB_ID,		'!isset({form})'],
+	'hostid' =>					[T_ZBX_INT, O_OPT, P_SYS,	DB_ID,		'isset({form}) && !isset({itemid})'],
 	'itemid' =>					[T_ZBX_INT, O_NO,	P_SYS,	DB_ID,		'(isset({form}) && ({form} == "update"))'],
 	'interfaceid' =>			[T_ZBX_INT, O_OPT, P_SYS,	DB_ID, null, _('Interface')],
 	'name' =>					[T_ZBX_STR, O_OPT, null,	NOT_EMPTY, 'isset({add}) || isset({update})', _('Name')],
@@ -56,17 +58,18 @@ $fields = [
 	'delay' =>					[T_ZBX_TU, O_OPT, P_ALLOW_USER_MACRO, null,
 									'(isset({add}) || isset({update})) && isset({type})'.
 										' && {type} != '.ITEM_TYPE_TRAPPER.' && {type} != '.ITEM_TYPE_SNMPTRAP.
-										' && {type} != '.ITEM_TYPE_DEPENDENT,
+										' && {type} != '.ITEM_TYPE_DEPENDENT.
+										' && !({type} == '.ITEM_TYPE_ZABBIX_ACTIVE.
+											' && isset({key}) && strncmp({key}, "mqtt.get", 8) === 0)',
 									_('Update interval')
 								],
 	'delay_flex' =>				[T_ZBX_STR, O_OPT, null,	null,			null],
 	'status' =>					[T_ZBX_INT, O_OPT, null,	IN(ITEM_STATUS_ACTIVE), null],
 	'type' =>					[T_ZBX_INT, O_OPT, null,
-									IN([-1, ITEM_TYPE_ZABBIX, ITEM_TYPE_SNMPV1, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE,
-										ITEM_TYPE_SNMPV2C, ITEM_TYPE_INTERNAL, ITEM_TYPE_SNMPV3,
+									IN([-1, ITEM_TYPE_ZABBIX, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE, ITEM_TYPE_INTERNAL,
 										ITEM_TYPE_ZABBIX_ACTIVE, ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR,
 										ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET, ITEM_TYPE_JMX,
-										ITEM_TYPE_DEPENDENT, ITEM_TYPE_HTTPAGENT
+										ITEM_TYPE_DEPENDENT, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT
 									]),
 									'isset({add}) || isset({update})'
 								],
@@ -91,53 +94,16 @@ $fields = [
 								],
 	$paramsFieldName =>			[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,	'(isset({add}) || isset({update}))'.
 									' && isset({type}) && '.IN(ITEM_TYPE_SSH.','.ITEM_TYPE_DB_MONITOR.','.
-										ITEM_TYPE_TELNET.','.ITEM_TYPE_CALCULATED, 'type'
+										ITEM_TYPE_TELNET.','.ITEM_TYPE_CALCULATED.','.ITEM_TYPE_SCRIPT, 'type'
 									),
 									getParamFieldLabelByType(getRequest('type', 0))
 								],
-	'snmp_community' =>			[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,
-									'(isset({add}) || isset({update})) && isset({type})'.
-										' && '.IN(ITEM_TYPE_SNMPV1.','.ITEM_TYPE_SNMPV2C, 'type'),
-									_('SNMP community')
-								],
 	'snmp_oid' =>				[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,
 									'(isset({add}) || isset({update})) && isset({type})'.
-										' && '.IN(ITEM_TYPE_SNMPV1.','.ITEM_TYPE_SNMPV2C.','.ITEM_TYPE_SNMPV3, 'type'),
+										' && {type} == '.ITEM_TYPE_SNMP,
 									_('SNMP OID')
 								],
-	'port' =>					[T_ZBX_STR, O_OPT, null,	BETWEEN(0, 65535),
-									'(isset({add}) || isset({update})) && isset({type})'.
-										' && '.IN(ITEM_TYPE_SNMPV1.','.ITEM_TYPE_SNMPV2C.','.ITEM_TYPE_SNMPV3, 'type'),
-									_('Port')
-								],
-	'snmpv3_contextname' =>		[T_ZBX_STR, O_OPT, null,	null,
-									'(isset({add}) || isset({update})) && isset({type}) && {type} == '.ITEM_TYPE_SNMPV3
-								],
-	'snmpv3_securitylevel' =>	[T_ZBX_INT, O_OPT, null,	IN('0,1,2'),
-									'(isset({add}) || isset({update})) && isset({type}) && {type} == '.ITEM_TYPE_SNMPV3
-								],
-	'snmpv3_securityname' =>	[T_ZBX_STR, O_OPT, null,	null,
-									'(isset({add}) || isset({update})) && isset({type}) && {type} == '.ITEM_TYPE_SNMPV3
-								],
-	'snmpv3_authprotocol' =>	[T_ZBX_INT, O_OPT, null, IN(ITEM_AUTHPROTOCOL_MD5.','.ITEM_AUTHPROTOCOL_SHA),
-									'(isset({add}) || isset({update})) && isset({type}) && {type} == '.ITEM_TYPE_SNMPV3.
-										' && ({snmpv3_securitylevel} == '.ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV.
-										' || {snmpv3_securitylevel}=='.ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV.')'
-								],
-	'snmpv3_authpassphrase' =>	[T_ZBX_STR, O_OPT, null, null,
-									'(isset({add}) || isset({update})) && isset({type}) && {type} == '.ITEM_TYPE_SNMPV3.
-										' && ({snmpv3_securitylevel} == '.ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV.
-										' || {snmpv3_securitylevel}=='.ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV.')'
-								],
-	'snmpv3_privprotocol' =>	[T_ZBX_INT, O_OPT, null, IN(ITEM_PRIVPROTOCOL_DES.','.ITEM_PRIVPROTOCOL_AES),
-									'(isset({add}) || isset({update})) && isset({type}) && {type} == '.ITEM_TYPE_SNMPV3.
-										' && {snmpv3_securitylevel} == '.ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV
-								],
-	'snmpv3_privpassphrase' =>	[T_ZBX_STR, O_OPT, null, null,
-									'(isset({add}) || isset({update})) && isset({type}) && {type} == '.ITEM_TYPE_SNMPV3.
-										' && {snmpv3_securitylevel} == '.ITEM_SNMPV3_SECURITYLEVEL_AUTHPRIV
-								],
-	'ipmi_sensor' =>			[T_ZBX_STR, O_OPT, P_NO_TRIM,	NOT_EMPTY,
+	'ipmi_sensor' =>			[T_ZBX_STR, O_OPT, P_NO_TRIM, null,
 									'(isset({add}) || isset({update})) && isset({type}) && {type} == '.ITEM_TYPE_IPMI,
 									_('IPMI sensor')
 								],
@@ -152,13 +118,18 @@ $fields = [
 	'jmx_endpoint' =>			[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,
 		'(isset({add}) || isset({update})) && isset({type}) && {type} == '.ITEM_TYPE_JMX
 	],
-	'timeout' =>				[T_ZBX_STR, O_OPT, null,	null,		null],
+	'timeout' => 				[T_ZBX_TU, O_OPT, P_ALLOW_USER_MACRO,	null,
+									'(isset({add}) || isset({update})) && isset({type})'.
+										' && '.IN(ITEM_TYPE_HTTPAGENT.','.ITEM_TYPE_SCRIPT, 'type'),
+									_('Timeout')
+								],
 	'url' =>					[T_ZBX_STR, O_OPT, null,	NOT_EMPTY,
 									'(isset({add}) || isset({update})) && isset({type})'.
 										' && {type} == '.ITEM_TYPE_HTTPAGENT,
 									_('URL')
 								],
 	'query_fields' =>			[T_ZBX_STR, O_OPT, null,	null,		null],
+	'parameters' =>				[T_ZBX_STR, O_OPT, null,	null,		null],
 	'posts' =>					[T_ZBX_STR, O_OPT, null,	null,		null],
 	'status_codes' =>			[T_ZBX_STR, O_OPT, null,	null,		null],
 	'follow_redirects' =>		[T_ZBX_INT, O_OPT, null,
@@ -199,7 +170,7 @@ $fields = [
 								],
 	'http_authtype' =>			[T_ZBX_INT, O_OPT, null,
 									IN([HTTPTEST_AUTH_NONE, HTTPTEST_AUTH_BASIC, HTTPTEST_AUTH_NTLM,
-										HTTPTEST_AUTH_KERBEROS
+										HTTPTEST_AUTH_KERBEROS, HTTPTEST_AUTH_DIGEST
 									]),
 									null
 								],
@@ -207,17 +178,22 @@ $fields = [
 									'(isset({add}) || isset({update})) && isset({http_authtype})'.
 										' && ({http_authtype} == '.HTTPTEST_AUTH_BASIC.
 											' || {http_authtype} == '.HTTPTEST_AUTH_NTLM.
-											' || {http_authtype} == '.HTTPTEST_AUTH_KERBEROS.')',
+											' || {http_authtype} == '.HTTPTEST_AUTH_KERBEROS.
+											' || {http_authtype} == '.HTTPTEST_AUTH_DIGEST.
+										')',
 									_('Username')
 								],
 	'http_password' =>			[T_ZBX_STR, O_OPT, null,	null,
 									'(isset({add}) || isset({update})) && isset({http_authtype})'.
 										' && ({http_authtype} == '.HTTPTEST_AUTH_BASIC.
 											' || {http_authtype} == '.HTTPTEST_AUTH_NTLM.
-											' || {http_authtype} == '.HTTPTEST_AUTH_KERBEROS.')',
+											' || {http_authtype} == '.HTTPTEST_AUTH_KERBEROS.
+											' || {http_authtype} == '.HTTPTEST_AUTH_DIGEST.
+										')',
 									_('Password')
 								],
 	'preprocessing' =>			[T_ZBX_STR, O_OPT, P_NO_TRIM,	null,	null],
+	'overrides' =>				[T_ZBX_STR, O_OPT, P_NO_TRIM,	null,	null],
 	// actions
 	'action' =>					[T_ZBX_STR, O_OPT, P_SYS|P_ACT,
 									IN('"discoveryrule.massdelete","discoveryrule.massdisable",'.
@@ -234,6 +210,30 @@ $fields = [
 	'check_now' =>				[T_ZBX_STR, O_OPT, P_SYS|P_ACT,	null,	null],
 	'form' =>					[T_ZBX_STR, O_OPT, P_SYS,	null,		null],
 	'form_refresh' =>			[T_ZBX_INT, O_OPT, null,	null,		null],
+	// filter
+	'filter_set' =>				[T_ZBX_STR, O_OPT, null,	null,		null],
+	'filter_rst' =>				[T_ZBX_STR, O_OPT, null,	null,		null],
+	'filter_groupids' =>		[T_ZBX_INT, O_OPT, null,	DB_ID,		null],
+	'filter_hostids' =>			[T_ZBX_INT, O_OPT, null,	DB_ID,		null],
+	'filter_name' =>			[T_ZBX_STR, O_OPT, null,	null,		null],
+	'filter_key' =>				[T_ZBX_STR, O_OPT, null,	null,		null],
+	'filter_type' =>			[T_ZBX_INT, O_OPT, null,
+									IN([-1, ITEM_TYPE_ZABBIX, ITEM_TYPE_TRAPPER, ITEM_TYPE_SIMPLE, ITEM_TYPE_INTERNAL,
+										ITEM_TYPE_ZABBIX_ACTIVE, ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR,
+										ITEM_TYPE_IPMI, ITEM_TYPE_SSH, ITEM_TYPE_TELNET, ITEM_TYPE_JMX,
+										ITEM_TYPE_DEPENDENT, ITEM_TYPE_HTTPAGENT, ITEM_TYPE_SNMP, ITEM_TYPE_SCRIPT
+									]),
+									null
+								],
+	'filter_delay' =>			[T_ZBX_STR, O_OPT, P_UNSET_EMPTY, null, null, _('Update interval')],
+	'filter_lifetime' =>		[T_ZBX_STR, O_OPT, null,	null,		null],
+	'filter_snmp_oid' =>		[T_ZBX_STR, O_OPT, null,	null,		null],
+	'filter_state' =>			[T_ZBX_INT, O_OPT, null,	IN([-1, ITEM_STATE_NORMAL, ITEM_STATE_NOTSUPPORTED]),
+									null
+								],
+	'filter_status' =>			[T_ZBX_INT, O_OPT, null,	IN([-1, ITEM_STATUS_ACTIVE, ITEM_STATUS_DISABLED]),
+									null
+								],
 	// sort and sortorder
 	'sort' =>					[T_ZBX_STR, O_OPT, P_SYS, IN('"delay","key_","name","status","type"'),	null],
 	'sortorder' =>				[T_ZBX_STR, O_OPT, P_SYS, IN('"'.ZBX_SORT_DOWN.'","'.ZBX_SORT_UP.'"'),	null]
@@ -247,6 +247,8 @@ $item = [];
 /*
  * Permissions
  */
+$hostid = getRequest('hostid', 0);
+
 if (getRequest('itemid', false)) {
 	$item = API::DiscoveryRule()->get([
 		'itemids' => getRequest('itemid'),
@@ -255,6 +257,7 @@ if (getRequest('itemid', false)) {
 		'selectFilter' => ['formula', 'evaltype', 'conditions'],
 		'selectLLDMacroPaths' => ['lld_macro', 'path'],
 		'selectPreprocessing' => ['type', 'params', 'error_handler', 'error_handler_params'],
+		'selectOverrides' => ['name', 'step', 'stop', 'filter', 'operations'],
 		'editable' => true
 	]);
 	$item = reset($item);
@@ -264,10 +267,10 @@ if (getRequest('itemid', false)) {
 	$_REQUEST['hostid'] = $item['hostid'];
 	$host = reset($item['hosts']);
 }
-else {
+elseif ($hostid) {
 	$hosts = API::Host()->get([
-		'output' => ['hostid', 'name', 'status', 'flags'],
-		'hostids' => getRequest('hostid'),
+		'output' => ['hostid', 'name', 'status'],
+		'hostids' => $hostid,
 		'templated_hosts' => true,
 		'editable' => true
 	]);
@@ -277,6 +280,89 @@ else {
 	}
 }
 
+/**
+ * Filter.
+ */
+$sort_field = getRequest('sort', CProfile::get('web.'.$page['file'].'.sort', 'name'));
+$sort_order = getRequest('sortorder', CProfile::get('web.'.$page['file'].'.sortorder', ZBX_SORT_UP));
+
+CProfile::update('web.'.$page['file'].'.sort', $sort_field, PROFILE_TYPE_STR);
+CProfile::update('web.'.$page['file'].'.sortorder', $sort_order, PROFILE_TYPE_STR);
+
+if (hasRequest('filter_set')) {
+	CProfile::updateArray('web.host_discovery.filter.groupids', getRequest('filter_groupids', []), PROFILE_TYPE_ID);
+	CProfile::updateArray('web.host_discovery.filter.hostids', getRequest('filter_hostids', []), PROFILE_TYPE_ID);
+	CProfile::update('web.host_discovery.filter.name', getRequest('filter_name', ''), PROFILE_TYPE_STR);
+	CProfile::update('web.host_discovery.filter.key', getRequest('filter_key', ''), PROFILE_TYPE_STR);
+	CProfile::update('web.host_discovery.filter.type', getRequest('filter_type', -1), PROFILE_TYPE_INT);
+	CProfile::update('web.host_discovery.filter.delay', getRequest('filter_delay', ''), PROFILE_TYPE_STR);
+	CProfile::update('web.host_discovery.filter.lifetime', getRequest('filter_lifetime', ''), PROFILE_TYPE_STR);
+	CProfile::update('web.host_discovery.filter.snmp_oid', getRequest('filter_snmp_oid', ''), PROFILE_TYPE_STR);
+	CProfile::update('web.host_discovery.filter.state', getRequest('filter_state', -1), PROFILE_TYPE_INT);
+	CProfile::update('web.host_discovery.filter.status', getRequest('filter_status', -1), PROFILE_TYPE_INT);
+}
+elseif (hasRequest('filter_rst')) {
+	CProfile::deleteIdx('web.host_discovery.filter.groupids');
+
+	if (count(CProfile::getArray('web.host_discovery.filter.hostids', [])) != 1) {
+		CProfile::deleteIdx('web.host_discovery.filter.hostids');
+	}
+
+	CProfile::delete('web.host_discovery.filter.name');
+	CProfile::delete('web.host_discovery.filter.key');
+	CProfile::delete('web.host_discovery.filter.type');
+	CProfile::delete('web.host_discovery.filter.delay');
+	CProfile::delete('web.host_discovery.filter.lifetime');
+	CProfile::delete('web.host_discovery.filter.snmp_oid');
+	CProfile::delete('web.host_discovery.filter.state');
+	CProfile::delete('web.host_discovery.filter.status');
+}
+
+$filter = [
+	'groups' => CProfile::getArray('web.host_discovery.filter.groupids', []),
+	'hosts' => CProfile::getArray('web.host_discovery.filter.hostids', []),
+	'name' => CProfile::get('web.host_discovery.filter.name', ''),
+	'key' => CProfile::get('web.host_discovery.filter.key', ''),
+	'type' => CProfile::get('web.host_discovery.filter.type', -1),
+	'delay' => CProfile::get('web.host_discovery.filter.delay', ''),
+	'lifetime' => CProfile::get('web.host_discovery.filter.lifetime', ''),
+	'snmp_oid' => CProfile::get('web.host_discovery.filter.snmp_oid', ''),
+	'state' => CProfile::get('web.host_discovery.filter.state', -1),
+	'status' => CProfile::get('web.host_discovery.filter.status', -1)
+];
+
+$filter_groupids = [];
+$filter_hostids = [];
+
+// Get host groups.
+if ($filter['groups']) {
+	$filter['groups'] = CArrayHelper::renameObjectsKeys(API::HostGroup()->get([
+		'output' => ['groupid', 'name'],
+		'groupids' => $filter['groups'],
+		'editable' => true,
+		'preservekeys' => true
+	]), ['groupid' => 'id']);
+
+	$filter_groupids = getSubGroups(array_keys($filter['groups']));
+}
+
+// Get hosts.
+if ($filter['hosts']) {
+	$filter['hosts'] = CArrayHelper::renameObjectsKeys(API::Host()->get([
+		'output' => ['hostid', 'name'],
+		'hostids' => $filter['hosts'],
+		'templated_hosts' => true,
+		'editable' => true,
+		'preservekeys' => true
+	]), ['hostid' => 'id']);
+
+	$filter_hostids = array_keys($filter['hosts']);
+
+	sort($filter_hostids);
+}
+
+$checkbox_hash = crc32(implode('', $filter_hostids));
+
 // Convert CR+LF to LF in preprocessing script.
 if (hasRequest('preprocessing')) {
 	foreach ($_REQUEST['preprocessing'] as &$step) {
@@ -294,7 +380,7 @@ if (hasRequest('delete') && hasRequest('itemid')) {
 	$result = API::DiscoveryRule()->delete([getRequest('itemid')]);
 
 	if ($result) {
-		uncheckTableRows(getRequest('hostid'));
+		uncheckTableRows($checkbox_hash);
 	}
 	show_messages($result, _('Discovery rule deleted'), _('Cannot delete discovery rule'));
 
@@ -302,8 +388,10 @@ if (hasRequest('delete') && hasRequest('itemid')) {
 }
 elseif (hasRequest('check_now') && hasRequest('itemid')) {
 	$result = (bool) API::Task()->create([
-		'type' => ZBX_TM_TASK_CHECK_NOW,
-		'itemids' => getRequest('itemid')
+		'type' => ZBX_TM_DATA_TYPE_CHECK_NOW,
+		'request' => [
+			'itemid' => getRequest('itemid')
+		]
 	]);
 
 	show_messages($result, _('Request sent successfully'), _('Cannot send request'));
@@ -318,7 +406,9 @@ elseif (hasRequest('add') || hasRequest('update')) {
 	 * "delay_flex" is a temporary field that collects flexible and scheduling intervals separated by a semicolon.
 	 * In the end, custom intervals together with "delay" are stored in the "delay" variable.
 	 */
-	if ($type != ITEM_TYPE_TRAPPER && $type != ITEM_TYPE_SNMPTRAP && hasRequest('delay_flex')) {
+	if ($type != ITEM_TYPE_TRAPPER && $type != ITEM_TYPE_SNMPTRAP
+			&& ($type != ITEM_TYPE_ZABBIX_ACTIVE || strncmp(getRequest('key'), 'mqtt.get', 8) !== 0)
+			&& hasRequest('delay_flex')) {
 		$intervals = [];
 		$simple_interval_parser = new CSimpleIntervalParser(['usermacros' => true]);
 		$time_period_parser = new CTimePeriodParser(['usermacros' => true]);
@@ -335,7 +425,8 @@ elseif (hasRequest('add') || hasRequest('update')) {
 					info(_s('Invalid interval "%1$s".', $interval['delay']));
 					break;
 				}
-				elseif ($time_period_parser->parse($interval['period']) != CParser::PARSE_SUCCESS) {
+
+				if ($time_period_parser->parse($interval['period']) != CParser::PARSE_SUCCESS) {
 					$result = false;
 					info(_s('Invalid interval "%1$s".', $interval['period']));
 					break;
@@ -383,6 +474,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 					break;
 
 				case ZBX_PREPROC_REGSUB:
+				case ZBX_PREPROC_STR_REPLACE:
 					$step['params'] = implode("\n", $step['params']);
 					break;
 
@@ -415,17 +507,8 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			'delay' => $delay,
 			'status' => getRequest('status', ITEM_STATUS_DISABLED),
 			'type' => getRequest('type'),
-			'snmp_community' => getRequest('snmp_community'),
 			'snmp_oid' => getRequest('snmp_oid'),
 			'trapper_hosts' => getRequest('trapper_hosts'),
-			'port' => getRequest('port'),
-			'snmpv3_contextname' => getRequest('snmpv3_contextname'),
-			'snmpv3_securityname' => getRequest('snmpv3_securityname'),
-			'snmpv3_securitylevel' => getRequest('snmpv3_securitylevel'),
-			'snmpv3_authprotocol' => getRequest('snmpv3_authprotocol'),
-			'snmpv3_authpassphrase' => getRequest('snmpv3_authpassphrase'),
-			'snmpv3_privprotocol' => getRequest('snmpv3_privprotocol'),
-			'snmpv3_privpassphrase' => getRequest('snmpv3_privpassphrase'),
 			'authtype' => getRequest('authtype'),
 			'username' => getRequest('username'),
 			'password' => getRequest('password'),
@@ -463,6 +546,15 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			$newItem = prepareItemHttpAgentFormData($http_item) + $newItem;
 		}
 
+		if ($newItem['type'] == ITEM_TYPE_SCRIPT) {
+			$script_item = [
+				'parameters' => getRequest('parameters', []),
+				'timeout' => getRequest('timeout', DB::getDefault('items', 'timeout'))
+			];
+
+			$newItem = prepareScriptItemFormData($script_item) + $newItem;
+		}
+
 		if ($newItem['type'] == ITEM_TYPE_JMX) {
 			$newItem['jmx_endpoint'] = getRequest('jmx_endpoint', '');
 		}
@@ -472,7 +564,7 @@ elseif (hasRequest('add') || hasRequest('update')) {
 		}
 
 		// add macros; ignore empty new macros
-		$filter = [
+		$lld_rule_filter = [
 			'evaltype' => getRequest('evaltype'),
 			'conditions' => []
 		];
@@ -483,20 +575,20 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			if (!zbx_empty($condition['macro'])) {
 				$condition['macro'] = mb_strtoupper($condition['macro']);
 
-				$filter['conditions'][] = $condition;
+				$lld_rule_filter['conditions'][] = $condition;
 			}
 		}
-		if ($filter['evaltype'] == CONDITION_EVAL_TYPE_EXPRESSION) {
+		if ($lld_rule_filter['evaltype'] == CONDITION_EVAL_TYPE_EXPRESSION) {
 			// if only one or no conditions are left, reset the evaltype to and/or and clear the formula
-			if (count($filter['conditions']) <= 1) {
-				$filter['formula'] = '';
-				$filter['evaltype'] = CONDITION_EVAL_TYPE_AND_OR;
+			if (count($lld_rule_filter['conditions']) <= 1) {
+				$lld_rule_filter['formula'] = '';
+				$lld_rule_filter['evaltype'] = CONDITION_EVAL_TYPE_AND_OR;
 			}
 			else {
-				$filter['formula'] = getRequest('formula');
+				$lld_rule_filter['formula'] = getRequest('formula');
 			}
 		}
-		$newItem['filter'] = $filter;
+		$newItem['filter'] = $lld_rule_filter;
 
 		$lld_macro_paths = getRequest('lld_macro_paths', []);
 
@@ -513,20 +605,26 @@ elseif (hasRequest('add') || hasRequest('update')) {
 			}
 		}
 
+		$overrides = getRequest('overrides', []);
+		$newItem['overrides'] = $overrides;
+
 		if (hasRequest('update')) {
 			DBstart();
 
-			// unset snmpv3 fields
-			if ($newItem['snmpv3_securitylevel'] == ITEM_SNMPV3_SECURITYLEVEL_NOAUTHNOPRIV) {
-				$newItem['snmpv3_authprotocol'] = ITEM_AUTHPROTOCOL_MD5;
-				$newItem['snmpv3_privprotocol'] = ITEM_PRIVPROTOCOL_DES;
-			}
-			elseif ($newItem['snmpv3_securitylevel'] == ITEM_SNMPV3_SECURITYLEVEL_AUTHNOPRIV) {
-				$newItem['snmpv3_privprotocol'] = ITEM_PRIVPROTOCOL_DES;
+			// Unset equal values if item script type and parameters have not changed.
+			$compare = function($arr, $arr2) {
+				return (array_combine(array_column($arr, 'name'), array_column($arr, 'value')) ==
+					array_combine(array_column($arr2, 'name'), array_column($arr2, 'value'))
+				);
+			};
+			if ($newItem['type'] == ITEM_TYPE_SCRIPT && $newItem['type'] == $item['type']
+					&& $compare($item['parameters'], $newItem['parameters'])) {
+				unset($newItem['parameters']);
 			}
 
-			// unset unchanged values
-			$newItem = CArrayHelper::unsetEqualValues($newItem, $item, ['itemid']);
+			if ($newItem['type'] == $item['type']) {
+				$newItem = CArrayHelper::unsetEqualValues($newItem, $item, ['itemid']);
+			}
 
 			// don't update the filter if it hasn't changed
 			$conditionsChanged = false;
@@ -542,8 +640,8 @@ elseif (hasRequest('add') || hasRequest('update')) {
 					}
 				}
 			}
-			$filter = CArrayHelper::unsetEqualValues($newItem['filter'], $item['filter']);
-			if (!isset($filter['evaltype']) && !isset($filter['formula']) && !$conditionsChanged) {
+			$lld_rule_filter = CArrayHelper::unsetEqualValues($newItem['filter'], $item['filter']);
+			if (!isset($lld_rule_filter['evaltype']) && !isset($lld_rule_filter['formula']) && !$conditionsChanged) {
 				unset($newItem['filter']);
 			}
 
@@ -597,12 +695,12 @@ elseif (hasRequest('add') || hasRequest('update')) {
 
 	if ($result) {
 		unset($_REQUEST['itemid'], $_REQUEST['form']);
-		uncheckTableRows(getRequest('hostid'));
+		uncheckTableRows($checkbox_hash);
 	}
 }
 elseif (hasRequest('action') && str_in_array(getRequest('action'), ['discoveryrule.massenable', 'discoveryrule.massdisable']) && hasRequest('g_hostdruleid')) {
 	$itemids = getRequest('g_hostdruleid');
-	$status = (getRequest('action') == 'discoveryrule.massenable') ? ITEM_STATUS_ACTIVE : ITEM_STATUS_DISABLED;
+	$status = (getRequest('action') === 'discoveryrule.massenable') ? ITEM_STATUS_ACTIVE : ITEM_STATUS_DISABLED;
 
 	$lld_rules = [];
 	foreach ($itemids as $itemid) {
@@ -612,7 +710,7 @@ elseif (hasRequest('action') && str_in_array(getRequest('action'), ['discoveryru
 	$result = (bool) API::DiscoveryRule()->update($lld_rules);
 
 	if ($result) {
-		uncheckTableRows(getRequest('hostid'));
+		uncheckTableRows($checkbox_hash);
 	}
 
 	$updated = count($itemids);
@@ -630,18 +728,26 @@ elseif (hasRequest('action') && getRequest('action') === 'discoveryrule.massdele
 	$result = API::DiscoveryRule()->delete(getRequest('g_hostdruleid'));
 
 	if ($result) {
-		uncheckTableRows(getRequest('hostid'));
+		uncheckTableRows($checkbox_hash);
 	}
 	show_messages($result, _('Discovery rules deleted'), _('Cannot delete discovery rules'));
 }
 elseif (hasRequest('action') && getRequest('action') === 'discoveryrule.masscheck_now' && hasRequest('g_hostdruleid')) {
-	$result = (bool) API::Task()->create([
-		'type' => ZBX_TM_TASK_CHECK_NOW,
-		'itemids' => getRequest('g_hostdruleid')
-	]);
+	$tasks = [];
+
+	foreach (getRequest('g_hostdruleid') as $taskid) {
+		$tasks[] = [
+			'type' => ZBX_TM_DATA_TYPE_CHECK_NOW,
+			'request' => [
+				'itemid' => $taskid
+			]
+		];
+	}
+
+	$result = (bool) API::Task()->create($tasks);
 
 	if ($result) {
-		uncheckTableRows(getRequest('hostid'));
+		uncheckTableRows($checkbox_hash);
 	}
 
 	show_messages($result, _('Request sent successfully'), _('Cannot send request'));
@@ -653,7 +759,7 @@ if (hasRequest('action') && hasRequest('g_hostdruleid') && !$result) {
 		'itemids' => getRequest('g_hostdruleid'),
 		'editable' => true
 	]);
-	uncheckTableRows(getRequest('hostid'), zbx_objectValues($hostdrules, 'itemid'));
+	uncheckTableRows($checkbox_hash, zbx_objectValues($hostdrules, 'itemid'));
 }
 
 /*
@@ -690,9 +796,12 @@ if (hasRequest('form')) {
 	$data['formula'] = getRequest('formula');
 	$data['conditions'] = getRequest('conditions', []);
 	$data['lld_macro_paths'] = getRequest('lld_macro_paths', []);
+	$data['overrides'] = getRequest('overrides', []);
 	$data['host'] = $host;
-	$data['preprocessing_test_type'] = CControllerPopupPreprocTestEdit::ZBX_TEST_TYPE_LLD;
+	$data['preprocessing_test_type'] = CControllerPopupItemTestEdit::ZBX_TEST_TYPE_LLD;
 	$data['preprocessing_types'] = CDiscoveryRule::$supported_preprocessing_types;
+	$data['display_interfaces'] = ($host['status'] == HOST_STATUS_MONITORED
+			|| $host['status'] == HOST_STATUS_NOT_MONITORED);
 
 	if (!hasRequest('form_refresh')) {
 		foreach ($data['preprocessing'] as &$step) {
@@ -713,6 +822,11 @@ if (hasRequest('form')) {
 		$data['formula'] = $item['filter']['formula'];
 		$data['conditions'] = $item['filter']['conditions'];
 		$data['lld_macro_paths'] = $item['lld_macro_paths'];
+		$data['overrides'] = $item['overrides'];
+		// Sort overrides to be listed in step order.
+		CArrayHelper::sort($data['overrides'], [
+			['field' => 'step', 'order' => ZBX_SORT_UP]
+		]);
 	}
 	// clone form
 	elseif (hasRequest('clone')) {
@@ -731,67 +845,150 @@ if (hasRequest('form')) {
 
 	// render view
 	if (!$has_errors) {
-		$itemView = new CView('configuration.host.discovery.edit', $data);
-		$itemView->render();
-		$itemView->show();
+		echo (new CView('configuration.host.discovery.edit', $data))->getOutput();
 	}
 }
 else {
-	$sortField = getRequest('sort', CProfile::get('web.'.$page['file'].'.sort', 'name'));
-	$sortOrder = getRequest('sortorder', CProfile::get('web.'.$page['file'].'.sortorder', ZBX_SORT_UP));
-
-	CProfile::update('web.'.$page['file'].'.sort', $sortField, PROFILE_TYPE_STR);
-	CProfile::update('web.'.$page['file'].'.sortorder', $sortOrder, PROFILE_TYPE_STR);
-
-	$config = select_config();
-
 	$data = [
-		'hostid' => getRequest('hostid', 0),
-		'host' => $host,
-		'showInfoColumn' => ($host['status'] != HOST_STATUS_TEMPLATE),
-		'sort' => $sortField,
-		'sortorder' => $sortOrder
+		'filter' => $filter,
+		'hostid' => (count($filter_hostids) == 1) ? reset($filter_hostids) : 0,
+		'sort' => $sort_field,
+		'sortorder' => $sort_order,
+		'profileIdx' => 'web.host_discovery.filter',
+		'active_tab' => CProfile::get('web.host_discovery.filter.active', 1),
+		'checkbox_hash' => $checkbox_hash,
+		'is_template' => true
 	];
 
-	// discoveries
-	$data['discoveries'] = API::DiscoveryRule()->get([
-		'hostids' => $data['hostid'],
+	// Select LLD rules.
+	$options = [
 		'output' => API_OUTPUT_EXTEND,
-		'editable' => true,
+		'selectHosts' => ['hostid', 'name', 'status', 'flags'],
 		'selectItems' => API_OUTPUT_COUNT,
 		'selectGraphs' => API_OUTPUT_COUNT,
 		'selectTriggers' => API_OUTPUT_COUNT,
 		'selectHostPrototypes' => API_OUTPUT_COUNT,
-		'sortfield' => $sortField,
-		'limit' => $config['search_limit'] + 1
-	]);
+		'editable' => true,
+		'filter' => [],
+		'search' => [],
+		'sortfield' => $sort_field,
+		'limit' => CSettingsHelper::get(CSettingsHelper::SEARCH_LIMIT) + 1
+	];
 
+	if ($filter_groupids) {
+		$options['groupids'] = $filter_groupids;
+	}
+
+	if ($filter_hostids) {
+		$options['hostids'] = $filter_hostids;
+	}
+
+	if ($filter['name'] !== '') {
+		$options['search']['name'] = $filter['name'];
+	}
+
+	if ($filter['key'] !== '') {
+		$options['search']['key_'] = $filter['key'];
+	}
+
+	if ($filter['type'] != -1) {
+		$options['filter']['type'] = $filter['type'];
+	}
+
+	/*
+	 * Trapper and SNMP trap items contain zeros in "delay" field and, if no specific type is set, look in item types
+	 * other than trapper and SNMP trap that allow zeros. For example, when a flexible interval is used. Since trapper
+	 * and SNMP trap items contain zeros, but those zeros should not be displayed, they cannot be filtered by entering
+	 * either zero or any other number in filter field.
+	 */
+	if ($filter['delay'] !== '') {
+		if ($filter['type'] == -1 && $filter['delay'] == 0) {
+			$options['filter']['type'] = [ITEM_TYPE_ZABBIX, ITEM_TYPE_SIMPLE,  ITEM_TYPE_INTERNAL,
+				ITEM_TYPE_ZABBIX_ACTIVE, ITEM_TYPE_EXTERNAL, ITEM_TYPE_DB_MONITOR, ITEM_TYPE_IPMI,
+				ITEM_TYPE_SSH, ITEM_TYPE_TELNET, ITEM_TYPE_JMX
+			];
+			$options['filter']['delay'] = $filter['delay'];
+		}
+		elseif ($filter['type'] == ITEM_TYPE_TRAPPER || $filter['type'] == ITEM_TYPE_DEPENDENT
+				|| ($filter['type'] == ITEM_TYPE_ZABBIX_ACTIVE && strncmp($filter['key'], 'mqtt.get', 8) === 0)) {
+			$options['filter']['delay'] = -1;
+		}
+		else {
+			$options['filter']['delay'] = $filter['delay'];
+		}
+	}
+
+	if ($filter['lifetime'] !== '') {
+		$options['filter']['lifetime'] = $filter['lifetime'];
+	}
+
+	if ($filter['snmp_oid'] !== '') {
+		$options['filter']['snmp_oid'] = $filter['snmp_oid'];
+	}
+
+	if ($filter['status'] != -1) {
+		$options['filter']['status'] = $filter['status'];
+	}
+
+	if ($filter['state'] != -1) {
+		$options['filter']['status'] = ITEM_STATUS_ACTIVE;
+		$options['filter']['state'] = $filter['state'];
+	}
+
+	$data['discoveries'] = API::DiscoveryRule()->get($options);
 	$data['discoveries'] = CMacrosResolverHelper::resolveItemNames($data['discoveries']);
 
-	switch ($sortField) {
+	switch ($sort_field) {
 		case 'delay':
-			orderItemsByDelay($data['discoveries'], $sortOrder, ['usermacros' => true]);
+			orderItemsByDelay($data['discoveries'], $sort_order, ['usermacros' => true]);
 			break;
 
 		case 'status':
-			orderItemsByStatus($data['discoveries'], $sortOrder);
+			orderItemsByStatus($data['discoveries'], $sort_order);
 			break;
 
 		default:
-			order_result($data['discoveries'], $sortField, $sortOrder);
+			order_result($data['discoveries'], $sort_field, $sort_order);
 	}
 
-	// paging
-	$url = (new CUrl('host_discovery.php'))->setArgument('hostid', $data['hostid']);
-
 	$data['discoveries'] = expandItemNamesWithMasterItems($data['discoveries'], 'items');
-	$data['paging'] = getPagingLine($data['discoveries'], $sortOrder, $url);
+
+	// Set is_template false, when one of hosts is not template.
+	if ($data['discoveries']) {
+		$hosts_status = [];
+		foreach ($data['discoveries'] as $discovery) {
+			$hosts_status[$discovery['hosts'][0]['status']] = true;
+		}
+		foreach ($hosts_status as $key => $value) {
+			if ($key != HOST_STATUS_TEMPLATE) {
+				$data['is_template'] = false;
+				break;
+			}
+		}
+	}
+
+	// pager
+	if (hasRequest('page')) {
+		$page_num = getRequest('page');
+	}
+	elseif (isRequestMethod('get') && !hasRequest('cancel')) {
+		$page_num = 1;
+	}
+	else {
+		$page_num = CPagerHelper::loadPage($page['file']);
+	}
+
+	CPagerHelper::savePage($page['file'], $page_num);
+
+	$data['paging'] = CPagerHelper::paginate($page_num, $data['discoveries'], $sort_order,
+		new CUrl('host_discovery.php')
+	);
+
 	$data['parent_templates'] = getItemParentTemplates($data['discoveries'], ZBX_FLAG_DISCOVERY_RULE);
+	$data['allowed_ui_conf_templates'] = CWebUser::checkAccess(CRoleHelper::UI_CONFIGURATION_TEMPLATES);
 
 	// render view
-	$discoveryView = new CView('configuration.host.discovery.list', $data);
-	$discoveryView->render();
-	$discoveryView->show();
+	echo (new CView('configuration.host.discovery.list', $data))->getOutput();
 }
 
 require_once dirname(__FILE__).'/include/page_footer.php';
