@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -24,6 +24,13 @@
  */
 abstract class CGraphGeneral extends CApiService {
 
+	public const ACCESS_RULES = [
+		'get' => ['min_user_type' => USER_TYPE_ZABBIX_USER],
+		'create' => ['min_user_type' => USER_TYPE_ZABBIX_ADMIN],
+		'update' => ['min_user_type' => USER_TYPE_ZABBIX_ADMIN],
+		'delete' => ['min_user_type' => USER_TYPE_ZABBIX_ADMIN]
+	];
+
 	const ERROR_TEMPLATE_HOST_MIX = 'templateHostMix';
 	const ERROR_MISSING_GRAPH_NAME = 'missingGraphName';
 	const ERROR_MISSING_GRAPH_ITEMS = 'missingGraphItems';
@@ -484,10 +491,14 @@ abstract class CGraphGeneral extends CApiService {
 		switch (get_class($this)) {
 			case 'CGraph':
 				$error_cannot_set = _('Cannot set "%1$s" for graph "%2$s".');
+				$api_input_rules = ['type' => API_OBJECT, 'fields' => []];
 				break;
 
 			case 'CGraphPrototype':
 				$error_cannot_set = _('Cannot set "%1$s" for graph prototype "%2$s".');
+				$api_input_rules = ['type' => API_OBJECT, 'fields' => [
+					'discover' => ['type' => API_INT32, 'in' => implode(',', [GRAPH_DISCOVER, GRAPH_NO_DISCOVER])]
+				]];
 				break;
 
 			default:
@@ -496,10 +507,17 @@ abstract class CGraphGeneral extends CApiService {
 
 		$read_only_fields = ['templateid', 'flags'];
 
-		foreach ($graphs as $graph) {
+		foreach ($graphs as $key => $graph) {
 			$this->checkNoParameters($graph, $read_only_fields, $error_cannot_set, $graph['name']);
 
+			$data = array_intersect_key($graph, $api_input_rules['fields']);
+
+			if (!CApiInputValidator::validate($api_input_rules, $data, '/'.($key + 1), $error)) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+			}
+
 			$templatedGraph = false;
+
 			if (isset($graph['gitems'])) {
 				// check if new items are from same templated host
 				$graphHosts = API::Host()->get([
@@ -615,10 +633,14 @@ abstract class CGraphGeneral extends CApiService {
 		switch (get_class($this)) {
 			case 'CGraph':
 				$error_cannot_update = _('Cannot update "%1$s" for graph "%2$s".');
+				$api_input_rules = ['type' => API_OBJECT, 'fields' => []];
 				break;
 
 			case 'CGraphPrototype':
 				$error_cannot_update = _('Cannot update "%1$s" for graph prototype "%2$s".');
+				$api_input_rules = ['type' => API_OBJECT, 'fields' => [
+					'discover' => ['type' => API_INT32, 'in' => implode(',', [GRAPH_DISCOVER, GRAPH_NO_DISCOVER])]
+				]];
 				break;
 
 			default:
@@ -627,9 +649,15 @@ abstract class CGraphGeneral extends CApiService {
 
 		$read_only_fields = ['templateid', 'flags'];
 
-		foreach ($graphs as $graph) {
+		foreach ($graphs as $key => $graph) {
 			$this->checkNoParameters($graph, $read_only_fields, $error_cannot_update, $graph['name']);
 
+			$data = array_intersect_key($graph, $api_input_rules['fields']);
+
+			if (!CApiInputValidator::validate($api_input_rules, $data, '/'.($key + 1), $error)) {
+				self::exception(ZBX_API_ERROR_PARAMETERS, $error);
+			}
+
 			$templatedGraph = false;
 
 			if (isset($graph['gitems'])) {
