@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -1239,7 +1239,7 @@ class CConfigurationExport {
 			$image = [
 				'name' => $image['name'],
 				'imagetype' => $image['imagetype'],
-				'encodedImage' => $image['image'],
+				'encodedImage' => $image['image']
 			];
 		}
 		unset($image);
