@@ -1,7 +1,7 @@
 <?php declare(strict_types = 1);
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -57,6 +57,13 @@ class CRouter {
 		// action						controller											layout					view
 		'action.operation.get'			=> ['CControllerActionOperationGet',				'layout.json',			null],
 		'action.operation.validate'		=> ['CControllerActionOperationValidate',			'layout.json',			null],
+		'application.create'			=> ['CControllerApplicationCreate',					null,					null],
+		'application.delete'			=> ['CControllerApplicationDelete',					null,					null],
+		'application.disable'			=> ['CControllerApplicationDisable',				null,					null],
+		'application.edit'				=> ['CControllerApplicationEdit',					'layout.htmlpage',		'configuration.application.edit'],
+		'application.enable'			=> ['CControllerApplicationEnable',					null,					null],
+		'application.list'				=> ['CControllerApplicationList',					'layout.htmlpage',		'configuration.application.list'],
+		'application.update'			=> ['CControllerApplicationUpdate',					null,					null],
 		'auditlog.list'					=> ['CControllerAuditLogList',						'layout.htmlpage',		'reports.auditlog.list'],
 		'authentication.edit'			=> ['CControllerAuthenticationEdit',				'layout.htmlpage',		'administration.authentication.edit'],
 		'authentication.update'			=> ['CControllerAuthenticationUpdate',				null,					null],
@@ -68,7 +75,7 @@ class CRouter {
 		'dashboard.list'				=> ['CControllerDashboardList',						'layout.htmlpage',		'monitoring.dashboard.list'],
 		'dashboard.properties.check'	=> ['CControllerDashboardPropertiesCheck',			'layout.json',			null],
 		'dashboard.properties.edit'		=> ['CControllerDashboardPropertiesEdit',			'layout.json',			'dashboard.properties.edit'],
-		'dashboard.share.edit'			=> ['CControllerDashboardShareEdit',				'layout.json',			'dashboard.sharing.edit'],
+		'dashboard.share.edit'			=> ['CControllerDashboardShareEdit',				'layout.json',			'dashboard.share.edit'],
 		'dashboard.share.update'		=> ['CControllerDashboardShareUpdate',				'layout.json',			null],
 		'dashboard.update'				=> ['CControllerDashboardUpdate',					'layout.json',			null],
 		'dashboard.view'				=> ['CControllerDashboardView',						'layout.htmlpage',		'monitoring.dashboard.view'],
@@ -78,16 +85,18 @@ class CRouter {
 		'dashboard.widget.rfrate'		=> ['CControllerDashboardWidgetRfRate',				'layout.json',			null],
 		'dashboard.widget.sanitize'		=> ['CControllerDashboardWidgetSanitize',			'layout.json',			null],
 		'discovery.view'				=> ['CControllerDiscoveryView',						'layout.htmlpage',		'monitoring.discovery.view'],
-		'export.hosts.xml'				=> ['CControllerExportXml',							'layout.xml',			null],
-		'export.mediatypes.xml'			=> ['CControllerExportXml',							'layout.xml',			null],
-		'export.screens.xml'			=> ['CControllerExportXml',							'layout.xml',			null],
-		'export.sysmaps.xml'			=> ['CControllerExportXml',							'layout.xml',			null],
-		'export.templates.xml'			=> ['CControllerExportXml',							'layout.xml',			null],
-		'export.valuemaps.xml'			=> ['CControllerExportXml',							'layout.xml',			null],
+		'export.hosts'					=> ['CControllerExport',							'layout.export',		null],
+		'export.mediatypes'				=> ['CControllerExport',							'layout.export',		null],
+		'export.screens'				=> ['CControllerExport',							'layout.export',		null],
+		'export.sysmaps'				=> ['CControllerExport',							'layout.export',		null],
+		'export.templates'				=> ['CControllerExport',							'layout.export',		null],
+		'export.valuemaps'				=> ['CControllerExport',							'layout.export',		null],
 		'favourite.create'				=> ['CControllerFavouriteCreate',					'layout.javascript',	null],
 		'favourite.delete'				=> ['CControllerFavouriteDelete',					'layout.javascript',	null],
 		'gui.edit'						=> ['CControllerGuiEdit',							'layout.htmlpage',		'administration.gui.edit'],
 		'gui.update'					=> ['CControllerGuiUpdate',							null,					null],
+		'hint.box'						=> ['CControllerHintBox',							'layout.json',			'hint.box'],
+		'host.dashboard.view'			=> ['CControllerHostDashboardView',					'layout.htmlpage',		'monitoring.host.dashboard.view'],
 		'host.view'						=> ['CControllerHostView',							'layout.htmlpage',		'monitoring.host.view'],
 		'host.view.refresh'				=> ['CControllerHostViewRefresh',					'layout.json',			'monitoring.host.view.refresh'],
 		'hostmacros.list'				=> ['CControllerHostMacrosList',					'layout.json',			'hostmacros.list'],
@@ -148,12 +157,17 @@ class CRouter {
 		'popup.mediatypetest.send'		=> ['CControllerPopupMediatypeTestSend',			'layout.json',			null],
 		'popup.scriptexec'				=> ['CControllerPopupScriptExec',					'layout.json',			'popup.scriptexec'],
 		'popup.services'				=> ['CControllerPopupServices',						'layout.json',			'popup.services'],
+		'popup.tabfilter.delete'		=> ['CControllerPopupTabFilterDelete',				'layout.json',			null],
+		'popup.tabfilter.edit'			=> ['CControllerPopupTabFilterEdit',				'layout.json',			'popup.tabfilter.edit'],
+		'popup.tabfilter.update'		=> ['CControllerPopupTabFilterUpdate',				'layout.json',			null],
 		'popup.testtriggerexpr'			=> ['CControllerPopupTestTriggerExpr',				'layout.json',			'popup.testtriggerexpr'],
 		'popup.triggerexpr'				=> ['CControllerPopupTriggerExpr',					'layout.json',			'popup.triggerexpr'],
 		'popup.triggerwizard'			=> ['CControllerPopupTriggerWizard',				'layout.json',			'popup.triggerwizard'],
 		'problem.view'					=> ['CControllerProblemView',						'layout.htmlpage',		'monitoring.problem.view'],
+		'problem.view.refresh'			=> ['CControllerProblemViewRefresh',				'layout.json',			null],
 		'problem.view.csv'				=> ['CControllerProblemView',						'layout.csv',			'monitoring.problem.view'],
 		'profile.update'				=> ['CControllerProfileUpdate',						'layout.json',			null],
+		'tabfilter.profile.update'		=> ['CControllerTabFilterProfileUpdate',			'layout.json',			null],
 		'proxy.create'					=> ['CControllerProxyCreate',						null,					null],
 		'proxy.delete'					=> ['CControllerProxyDelete',						null,					null],
 		'proxy.edit'					=> ['CControllerProxyEdit',							'layout.htmlpage',		'administration.proxy.edit'],
@@ -176,13 +190,13 @@ class CRouter {
 		'script.update'					=> ['CControllerScriptUpdate',						null,					null],
 		'search'						=> ['CControllerSearch',							'layout.htmlpage',		'search'],
 		'system.warning'				=> ['CControllerSystemWarning',						'layout.warning',		'system.warning'],
+		'template.dashboard.delete'		=> ['CControllerTemplateDashboardDelete',			null,					null],
+		'template.dashboard.edit'		=> ['CControllerTemplateDashboardEdit',				'layout.htmlpage',		'configuration.dashboard.edit'],
+		'template.dashboard.list'		=> ['CControllerTemplateDashboardList',				'layout.htmlpage',		'configuration.dashboard.list'],
+		'template.dashboard.update'		=> ['CControllerTemplateDashboardUpdate',			'layout.json',			null],
 		'timeselector.update'			=> ['CControllerTimeSelectorUpdate',				'layout.json',			null],
 		'trigdisplay.edit'				=> ['CControllerTrigDisplayEdit',					'layout.htmlpage',		'administration.trigdisplay.edit'],
-		'trigdisplay.reset'				=> ['CControllerTrigDisplayReset',					null,					null],
 		'trigdisplay.update'			=> ['CControllerTrigDisplayUpdate',					null,					null],
-		'trigseverity.edit'				=> ['CControllerTrigSeverityEdit',					'layout.htmlpage',		'administration.trigseverity.edit'],
-		'trigseverity.reset'			=> ['CControllerTrigSeverityReset',					null,					null],
-		'trigseverity.update'			=> ['CControllerTrigSeverityUpdate',				null,					null],
 		'user.create'					=> ['CControllerUserCreate',						null,					null],
 		'user.delete'					=> ['CControllerUserDelete',						null,					null],
 		'user.edit'						=> ['CControllerUserEdit',							'layout.htmlpage',		'administration.user.edit'],
@@ -199,6 +213,11 @@ class CRouter {
 		'usergroup.update'				=> ['CControllerUsergroupUpdate',					null,					null],
 		'userprofile.edit'				=> ['CControllerUserProfileEdit',					'layout.htmlpage',		'administration.user.edit'],
 		'userprofile.update'			=> ['CControllerUserProfileUpdate',					null,					null],
+		'userrole.delete'				=> ['CControllerUserroleDelete',					null,					null],
+		'userrole.list'					=> ['CControllerUserroleList',						'layout.htmlpage',		'administration.userrole.list'],
+		'userrole.create'				=> ['CControllerUserroleCreate',					null,					null],
+		'userrole.edit'					=> ['CControllerUserroleEdit',						'layout.htmlpage',		'administration.userrole.edit'],
+		'userrole.update'				=> ['CControllerUserroleUpdate',					null,					null],
 		'valuemap.create'				=> ['CControllerValuemapCreate',					null,					null],
 		'valuemap.delete'				=> ['CControllerValuemapDelete',					null,					null],
 		'valuemap.edit'					=> ['CControllerValuemapEdit',						'layout.htmlpage',		'administration.valuemap.edit'],
@@ -228,8 +247,6 @@ class CRouter {
 		'widget.trigover.view'			=> ['CControllerWidgetTrigOverView',				'layout.widget',		'monitoring.widget.trigover.view'],
 		'widget.url.view'				=> ['CControllerWidgetUrlView',						'layout.widget',		'monitoring.widget.url.view'],
 		'widget.web.view'				=> ['CControllerWidgetWebView',						'layout.widget',		'monitoring.widget.web.view'],
-		'workingtime.edit'				=> ['CControllerWorkingTimeEdit',					'layout.htmlpage',		'administration.workingtime.edit'],
-		'workingtime.update'			=> ['CControllerWorkingTimeUpdate',					null,					null],
 
 		// legacy actions
 		'actionconf.php'				=> ['CLegacyAction', null, null],
@@ -243,7 +260,6 @@ class CRouter {
 		'adm.triggerseverities.php'		=> ['CLegacyAction', null, null],
 		'adm.valuemapping.php'			=> ['CLegacyAction', null, null],
 		'adm.workingtime.php'			=> ['CLegacyAction', null, null],
-		'applications.php'				=> ['CLegacyAction', null, null],
 		'auditacts.php'					=> ['CLegacyAction', null, null],
 		'browserwarning.php'			=> ['CLegacyAction', null, null],
 		'chart.php'						=> ['CLegacyAction', null, null],
@@ -261,7 +277,6 @@ class CRouter {
 		'history.php'					=> ['CLegacyAction', null, null],
 		'host_discovery.php'			=> ['CLegacyAction', null, null],
 		'host_prototypes.php'			=> ['CLegacyAction', null, null],
-		'host_screen.php'				=> ['CLegacyAction', null, null],
 		'hostgroups.php'				=> ['CLegacyAction', null, null],
 		'hostinventories.php'			=> ['CLegacyAction', null, null],
 		'hostinventoriesoverview.php'	=> ['CLegacyAction', null, null],
@@ -302,7 +317,7 @@ class CRouter {
 	];
 
 	/**
-	 * Add new actions (potentially overwritting the existing ones).
+	 * Add new actions (potentially overwriting the existing ones).
 	 *
 	 * @param array  $actions                           List of actions.
 	 * @param string $actions['action_name']            Definition of the 'action_name' action.
