@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -36,7 +36,7 @@ if (!empty($this->data['parent_discoveryid'])) {
 				))
 			))->setAttribute('aria-label', _('Content controls'))
 		)
-		->addItem(get_header_host_table('graphs', $this->data['hostid'], $this->data['parent_discoveryid']));
+		->setNavigation(getHostNavigation('graphs', $this->data['hostid'], $this->data['parent_discoveryid']));
 }
 else {
 	$widget = (new CWidget())
@@ -54,7 +54,7 @@ else {
 		);
 
 	if (!empty($this->data['hostid'])) {
-		$widget->addItem(get_header_host_table('graphs', $this->data['hostid']));
+		$widget->setNavigation(getHostNavigation('graphs', $this->data['hostid']));
 	}
 
 	// Add filter tab.
@@ -77,7 +77,8 @@ else {
 									'dstfrm' => 'zbx_filter',
 									'dstfld1' => 'filter_groups_',
 									'with_hosts_and_templates' => 1,
-									'editable' => 1
+									'editable' => 1,
+									'enrich_parent_groups' => true
 								]
 							]
 						]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
@@ -156,11 +157,9 @@ foreach ($data['graphs'] as $graph) {
 		$hostList = implode(', ', $hostList);
 	}
 
+	$flag = ($data['parent_discoveryid'] === null) ? ZBX_FLAG_DISCOVERY_NORMAL : ZBX_FLAG_DISCOVERY_PROTOTYPE;
 	$name = [];
-	$name[] = makeGraphTemplatePrefix($graphid, $data['parent_templates'], ($data['parent_discoveryid'] === null)
-		? ZBX_FLAG_DISCOVERY_NORMAL
-		: ZBX_FLAG_DISCOVERY_PROTOTYPE
-	);
+	$name[] = makeGraphTemplatePrefix($graphid, $data['parent_templates'], $flag, $data['allowed_ui_conf_templates']);
 
 	if ($graph['discoveryRule'] && $data['parent_discoveryid'] === null) {
 		$name[] = (new CLink(CHtml::encode($graph['discoveryRule']['name']),
@@ -201,7 +200,7 @@ foreach ($data['graphs'] as $graph) {
 				->addClass($nodiscover ? ZBX_STYLE_RED : ZBX_STYLE_GREEN);
 	}
 	else if (array_key_exists('ts_delete', $graph['graphDiscovery']) && $graph['graphDiscovery']['ts_delete'] > 0) {
-		$info_icons[] = getItemLifetimeIndicator(time(), $graph['graphDiscovery']['ts_delete']);
+		$info_icons[] = getGraphLifetimeIndicator(time(), $graph['graphDiscovery']['ts_delete']);
 	}
 
 	$graphTable->addRow([
