@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2017 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,15 +19,24 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 $widget = (new CWidget())
 	->setTitle(_('Host prototypes'))
-	->setControls((new CForm('get'))
-		->cleanItems()
-		->addVar('parent_discoveryid', $this->data['parent_discoveryid'])
-		->addItem((new CList())->addItem(new CSubmit('form', _('Create host prototype'))))
+	->setControls(
+		(new CTag('nav', true,
+			(new CList())->addItem(new CRedirectButton(_('Create host prototype'),
+				(new CUrl('host_prototypes.php'))
+					->setArgument('form', 'create')
+					->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+					->getUrl()
+			))
+		))->setAttribute('aria-label', _('Content controls'))
 	)
-	->addItem(
-		get_header_host_table('hosts', $this->data['discovery_rule']['hostid'], $this->data['parent_discoveryid'])
+	->setNavigation(
+		getHostNavigation('hosts', $this->data['discovery_rule']['hostid'], $this->data['parent_discoveryid'])
 	);
 
 // create form
@@ -35,37 +44,35 @@ $itemForm = (new CForm())
 	->setName('hosts')
 	->addVar('parent_discoveryid', $this->data['parent_discoveryid']);
 
+$url = (new CUrl('host_prototypes.php'))
+	->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+	->getUrl();
+
 // create table
 $hostTable = (new CTableInfo())
 	->setHeader([
 		(new CColHeader(
 			(new CCheckBox('all_hosts'))->onClick("checkAll('".$itemForm->getName()."', 'all_hosts', 'group_hostid');")
 		))->addClass(ZBX_STYLE_CELL_WIDTH),
-		make_sorting_header(_('Name'), 'name', $this->data['sort'], $this->data['sortorder']),
+		make_sorting_header(_('Name'), 'name', $data['sort'], $data['sortorder'], $url),
 		_('Templates'),
-		make_sorting_header(_('Create enabled'), 'status', $this->data['sort'], $this->data['sortorder'])
+		make_sorting_header(_('Create enabled'), 'status', $data['sort'], $data['sortorder'], $url),
+		make_sorting_header(_('Discover'), 'discover', $data['sort'], $data['sortorder'], $url),
+		_('Tags')
 	]);
 
 foreach ($this->data['hostPrototypes'] as $hostPrototype) {
 	// name
 	$name = [];
-	if ($hostPrototype['templateid']) {
-		$sourceTemplate = $hostPrototype['sourceTemplate'];
-
-		if (array_key_exists($sourceTemplate['hostid'], $data['writable_templates'])) {
-			$name[] = (new CLink($sourceTemplate['name'],
-				'?parent_discoveryid='.$hostPrototype['sourceDiscoveryRuleId']
-			))
-				->addClass(ZBX_STYLE_LINK_ALT)
-				->addClass(ZBX_STYLE_GREY);
-		}
-		else {
-			$name[] = (new CSpan($sourceTemplate['name']))->addClass(ZBX_STYLE_GREY);
-		}
-
-		$name[] = NAME_DELIMITER;
-	}
-	$name[] = new CLink($hostPrototype['name'], '?form=update&parent_discoveryid='.$this->data['discovery_rule']['itemid'].'&hostid='.$hostPrototype['hostid']);
+	$name[] = makeHostPrototypeTemplatePrefix($hostPrototype['hostid'], $data['parent_templates'],
+		$data['allowed_ui_conf_templates']
+	);
+	$name[] = new CLink(CHtml::encode($hostPrototype['name']),
+		(new CUrl('host_prototypes.php'))
+			->setArgument('form', 'update')
+			->setArgument('parent_discoveryid', $data['discovery_rule']['itemid'])
+			->setArgument('hostid', $hostPrototype['hostid'])
+	);
 
 	// template list
 	if (empty($hostPrototype['templates'])) {
@@ -78,7 +85,8 @@ foreach ($this->data['hostPrototypes'] as $hostPrototype) {
 		foreach ($hostPrototype['templates'] as $template) {
 			$caption = [];
 
-			if (array_key_exists($template['templateid'], $data['writable_templates'])) {
+			if ($data['allowed_ui_conf_templates']
+					&& array_key_exists($template['templateid'], $data['writable_templates'])) {
 				$caption[] = (new CLink($template['name'],
 					'templates.php?form=update&templateid='.$template['templateid']
 				))
@@ -136,16 +144,30 @@ foreach ($this->data['hostPrototypes'] as $hostPrototype) {
 		->addClass(itemIndicatorStyle($hostPrototype['status']))
 		->addSID();
 
+	$nodiscover = ($hostPrototype['discover'] == ZBX_PROTOTYPE_NO_DISCOVER);
+	$discover = (new CLink($nodiscover ? _('No') : _('Yes'),
+			(new CUrl('host_prototypes.php'))
+				->setArgument('hostid', $hostPrototype['hostid'])
+				->setArgument('parent_discoveryid', $data['discovery_rule']['itemid'])
+				->setArgument('action', 'hostprototype.updatediscover')
+				->setArgument('discover', $nodiscover ? ZBX_PROTOTYPE_DISCOVER : ZBX_PROTOTYPE_NO_DISCOVER)
+				->setArgumentSID()
+				->getUrl()
+		))
+			->addSID()
+			->addClass(ZBX_STYLE_LINK_ACTION)
+			->addClass($nodiscover ? ZBX_STYLE_RED : ZBX_STYLE_GREEN);
+
 	$hostTable->addRow([
 		new CCheckBox('group_hostid['.$hostPrototype['hostid'].']', $hostPrototype['hostid']),
 		$name,
 		$hostTemplates,
-		$status
+		$status,
+		$discover,
+		$data['tags'][$hostPrototype['hostid']]
 	]);
 }
 
-zbx_add_post_js('cookie.prefix = "'.$this->data['discovery_rule']['itemid'].'";');
-
 // append table to form
 $itemForm->addItem([
 	$hostTable,
@@ -153,10 +175,10 @@ $itemForm->addItem([
 	new CActionButtonList('action', 'group_hostid',
 		[
 			'hostprototype.massenable' => ['name' => _('Create enabled'),
-				'confirm' => _('Enable selected host prototypes?')
+				'confirm' => _('Create hosts from selected prototypes as enabled?')
 			],
 			'hostprototype.massdisable' => ['name' => _('Create disabled'),
-				'confirm' => _('Disable selected host prototypes?')
+				'confirm' => _('Create hosts from selected prototypes as disabled?')
 			],
 			'hostprototype.massdelete' => ['name' => _('Delete'),
 				'confirm' => _('Delete selected host prototypes?')
@@ -169,4 +191,4 @@ $itemForm->addItem([
 // append form to widget
 $widget->addItem($itemForm);
 
-return $widget;
+$widget->show();
