@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2019 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,6 +19,10 @@
 **/
 
 
+/**
+ * @var CView $this
+ */
+
 $widget = (new CWidget())
 	->setTitle(_('Item prototypes'))
 	->setControls(
@@ -31,12 +35,12 @@ $widget = (new CWidget())
 			))
 		))->setAttribute('aria-label', _('Content controls'))
 	)
-	->addItem(get_header_host_table('items', $this->data['hostid'], $this->data['parent_discoveryid']));
+	->setNavigation(getHostNavigation('items', $data['hostid'], $data['parent_discoveryid']));
 
 // create form
 $itemForm = (new CForm())
 	->setName('items')
-	->addVar('parent_discoveryid', $this->data['parent_discoveryid']);
+	->addVar('parent_discoveryid', $data['parent_discoveryid']);
 
 $url = (new CUrl('disc_prototypes.php'))
 	->setArgument('parent_discoveryid', $data['parent_discoveryid'])
@@ -56,14 +60,17 @@ $itemTable = (new CTableInfo())
 		make_sorting_header(_('Trends'), 'trends', $data['sort'], $data['sortorder'], $url),
 		make_sorting_header(_('Type'), 'type', $data['sort'], $data['sortorder'], $url),
 		_('Applications'),
-		make_sorting_header(_('Create enabled'), 'status', $data['sort'], $data['sortorder'], $url)
+		make_sorting_header(_('Create enabled'), 'status', $data['sort'], $data['sortorder'], $url),
+		make_sorting_header(_('Discover'), 'discover', $data['sort'], $data['sortorder'], $url)
 	]);
 
 $update_interval_parser = new CUpdateIntervalParser(['usermacros' => true, 'lldmacros' => true]);
 
 foreach ($data['items'] as $item) {
 	$description = [];
-	$description[] = makeItemTemplatePrefix($item['itemid'], $data['parent_templates'], ZBX_FLAG_DISCOVERY_PROTOTYPE);
+	$description[] = makeItemTemplatePrefix($item['itemid'], $data['parent_templates'], ZBX_FLAG_DISCOVERY_PROTOTYPE,
+		$data['allowed_ui_conf_templates']
+	);
 
 	if ($item['type'] == ITEM_TYPE_DEPENDENT) {
 		if ($item['master_item']['type'] == ITEM_TYPE_HTTPTEST) {
@@ -72,7 +79,9 @@ foreach ($data['items'] as $item) {
 		else {
 			$link = ($item['master_item']['source'] === 'itemprototypes')
 				? (new CUrl('disc_prototypes.php'))->setArgument('parent_discoveryid', $data['parent_discoveryid'])
-				: (new CUrl('items.php'))->setArgument('hostid', $item['hostid']);
+				: (new CUrl('items.php'))
+					->setArgument('filter_set', '1')
+					->setArgument('filter_hostids', [$item['hostid']]);
 
 			$description[] = (new CLink(CHtml::encode($item['master_item']['name_expanded']),
 				$link
@@ -130,7 +139,8 @@ foreach ($data['items'] as $item) {
 
 	// Hide zeros for trapper, SNMP trap and dependent items.
 	if ($item['type'] == ITEM_TYPE_TRAPPER || $item['type'] == ITEM_TYPE_SNMPTRAP
-			|| $item['type'] == ITEM_TYPE_DEPENDENT) {
+			|| $item['type'] == ITEM_TYPE_DEPENDENT
+			|| ($item['type'] == ITEM_TYPE_ZABBIX_ACTIVE && strncmp($item['key_'], 'mqtt.get', 8) === 0)) {
 		$item['delay'] = '';
 	}
 	elseif ($update_interval_parser->parse($item['delay']) == CParser::PARSE_SUCCESS) {
@@ -143,26 +153,40 @@ foreach ($data['items'] as $item) {
 		(new CButton(null))->addClass(ZBX_STYLE_ICON_WZRD_ACTION)->setMenuPopup($item_menu)
 	))->addClass(ZBX_STYLE_REL_CONTAINER);
 
+	$nodiscover = ($item['discover'] == ZBX_PROTOTYPE_NO_DISCOVER);
+	$discover = (new CLink($nodiscover ? _('No') : _('Yes'),
+			(new CUrl('disc_prototypes.php'))
+				->setArgument('group_itemid[]', $item['itemid'])
+				->setArgument('parent_discoveryid', $data['parent_discoveryid'])
+				->setArgument('visible[discover]', '1')
+				->setArgument('massupdate', 'discover')
+				->setArgument('discover', $nodiscover ? ZBX_PROTOTYPE_DISCOVER : ZBX_PROTOTYPE_NO_DISCOVER)
+				->setArgumentSID()
+				->getUrl()
+		))
+			->addSID()
+			->addClass(ZBX_STYLE_LINK_ACTION)
+			->addClass($nodiscover ? ZBX_STYLE_RED : ZBX_STYLE_GREEN);
+
 	$itemTable->addRow([
 		new CCheckBox('group_itemid['.$item['itemid'].']', $item['itemid']),
 		$wizard,
 		$description,
-		$item['key_'],
+		(new CDiv(CHtml::encode($item['key_'])))->addClass(ZBX_STYLE_WORDWRAP),
 		$item['delay'],
 		$item['history'],
 		$item['trends'],
 		item_type2str($item['type']),
 		$applications,
-		$status
+		$status,
+		$discover
 	]);
 }
 
-zbx_add_post_js('cookie.prefix = "'.$this->data['parent_discoveryid'].'";');
-
 // append table to form
 $itemForm->addItem([
 	$itemTable,
-	$this->data['paging'],
+	$data['paging'],
 	new CActionButtonList('action', 'group_itemid',
 		[
 			'itemprototype.massenable' => ['name' => _('Create enabled'),
@@ -171,15 +195,16 @@ $itemForm->addItem([
 			'itemprototype.massdisable' => ['name' => _('Create disabled'),
 				'confirm' => _('Create items from selected prototypes as disabled?')
 			],
+			'itemprototype.massupdateform' => ['name' => _('Mass update')],
 			'itemprototype.massdelete' => ['name' => _('Delete'),
 				'confirm' => _('Delete selected item prototypes?')
 			]
 		],
-		$this->data['parent_discoveryid']
+		$data['parent_discoveryid']
 	)
 ]);
 
 // append form to widget
 $widget->addItem($itemForm);
 
-return $widget;
+$widget->show();
