@@ -1,7 +1,7 @@
 <?php
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -23,6 +23,7 @@
  * @var CView $this
  */
 
+$this->includeJsFile('monitoring.screen.constructor.edit.js.php');
 $action = 'screenedit.php?form=update&screenid='.getRequest('screenid');
 if (isset($_REQUEST['screenitemid'])) {
 	$action .= '&screenitemid='.getRequest('screenitemid');
@@ -83,8 +84,12 @@ else {
 $screenResources = screen_resources();
 
 $screenFormList = (new CFormList())
-	->addRow((new CLabel(_('Resource'), 'resourcetype')),
-		(new CComboBox('resourcetype', $resourceType, 'submit()', $screenResources))
+	->addRow((new CLabel(_('Resource'), 'label-resourcetype')),
+		(new CSelect('resourcetype'))
+			->setId('resourcetype')
+			->setFocusableElementId('label-resourcetype')
+			->setValue($resourceType)
+			->addOptions(CSelect::createOptionsFromArray($screenResources))
 	);
 
 /*
@@ -449,7 +454,8 @@ elseif (in_array($resourceType, [SCREEN_RESOURCE_HOSTGROUP_TRIGGERS, SCREEN_RESO
 						'srcfld1' => 'groupid',
 						'dstfrm' => $form->getName(),
 						'dstfld1' => 'resourceid',
-						'real_hosts' => true
+						'real_hosts' => true,
+						'enrich_parent_groups' => true
 					]
 				]
 			]))->setWidth(ZBX_TEXTAREA_STANDARD_WIDTH)
@@ -500,12 +506,15 @@ elseif (in_array($resourceType, [SCREEN_RESOURCE_HOSTGROUP_TRIGGERS, SCREEN_RESO
 			->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
 	);
 	$screenFormList->addRow(
-		_('Sort triggers by'),
-		new CComboBox('sort_triggers', $sortTriggers, null, [
-			SCREEN_SORT_TRIGGERS_DATE_DESC => _('Last change (descending)'),
-			SCREEN_SORT_TRIGGERS_SEVERITY_DESC => _('Severity (descending)'),
-			SCREEN_SORT_TRIGGERS_HOST_NAME_ASC => _('Host (ascending)')
-		])
+		new CLabel(_('Sort triggers by'), 'label-sort-triggers'),
+		(new CSelect('sort_triggers'))
+			->setFocusableElementId('label-sort-triggers')
+			->setValue($sortTriggers)
+			->addOptions(CSelect::createOptionsFromArray([
+				SCREEN_SORT_TRIGGERS_DATE_DESC => _('Last change (descending)'),
+				SCREEN_SORT_TRIGGERS_SEVERITY_DESC => _('Severity (descending)'),
+				SCREEN_SORT_TRIGGERS_HOST_NAME_ASC => _('Host (ascending)')
+			]))
 	);
 }
 
@@ -520,17 +529,20 @@ elseif ($resourceType == SCREEN_RESOURCE_ACTIONS) {
 			->setWidth(ZBX_TEXTAREA_NUMERIC_STANDARD_WIDTH)
 	);
 	$screenFormList->addRow(
-		_('Sort entries by'),
-		new CComboBox('sort_triggers', $sortTriggers, null, [
-			SCREEN_SORT_TRIGGERS_TIME_DESC => _('Time (descending)'),
-			SCREEN_SORT_TRIGGERS_TIME_ASC => _('Time (ascending)'),
-			SCREEN_SORT_TRIGGERS_TYPE_DESC => _('Type (descending)'),
-			SCREEN_SORT_TRIGGERS_TYPE_ASC => _('Type (ascending)'),
-			SCREEN_SORT_TRIGGERS_STATUS_DESC => _('Status (descending)'),
-			SCREEN_SORT_TRIGGERS_STATUS_ASC => _('Status (ascending)'),
-			SCREEN_SORT_TRIGGERS_RECIPIENT_DESC => _('Recipient (descending)'),
-			SCREEN_SORT_TRIGGERS_RECIPIENT_ASC => _('Recipient (ascending)')
-		])
+		new CLabel(_('Sort entries by'), 'label-sort-triggers'),
+		(new CSelect('sort_triggers'))
+			->setFocusableElementId('label-sort-triggers')
+			->setValue($sortTriggers)
+			->addOptions(CSelect::createOptionsFromArray([
+				SCREEN_SORT_TRIGGERS_TIME_DESC => _('Time (descending)'),
+				SCREEN_SORT_TRIGGERS_TIME_ASC => _('Time (ascending)'),
+				SCREEN_SORT_TRIGGERS_TYPE_DESC => _('Type (descending)'),
+				SCREEN_SORT_TRIGGERS_TYPE_ASC => _('Type (ascending)'),
+				SCREEN_SORT_TRIGGERS_STATUS_DESC => _('Status (descending)'),
+				SCREEN_SORT_TRIGGERS_STATUS_ASC => _('Status (ascending)'),
+				SCREEN_SORT_TRIGGERS_RECIPIENT_DESC => _('Recipient (descending)'),
+				SCREEN_SORT_TRIGGERS_RECIPIENT_ASC => _('Recipient (ascending)')
+			]))
 	);
 }
 
@@ -659,11 +671,17 @@ elseif ($resourceType == SCREEN_RESOURCE_HOST_INFO || $resourceType == SCREEN_RE
 elseif ($resourceType == SCREEN_RESOURCE_CLOCK) {
 	$item = false;
 
-	$screenFormList->addRow(_('Time type'), new CComboBox('style', $style, 'submit()', [
-		TIME_TYPE_LOCAL => _('Local time'),
-		TIME_TYPE_SERVER => _('Server time'),
-		TIME_TYPE_HOST => _('Host time')
-	]));
+	$screenFormList->addRow(new CLabel(_('Time type'), 'label-time-type'),
+		(new CSelect('style'))
+			->setValue($style)
+			->setId('style')
+			->setFocusableElementId('label-time-type')
+			->addOptions(CSelect::createOptionsFromArray([
+				TIME_TYPE_LOCAL => _('Local time'),
+				TIME_TYPE_SERVER => _('Server time'),
+				TIME_TYPE_HOST => _('Host time')
+			]))
+	);
 
 	if ($style == TIME_TYPE_HOST) {
 		if ($resourceId > 0) {
