@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -45,6 +45,7 @@ jQuery(function($) {
 		ui_disabled = false;
 
 	endpoint.setArgument('action', 'timeselector.update');
+	endpoint.addSID();
 	endpoint.setArgument('type', 11); // PAGE_TYPE_TEXT_RETURN_JSON
 
 	$.subscribe('timeselector.rangechange timeselector.decrement timeselector.increment timeselector.zoomout' +
@@ -144,7 +145,8 @@ jQuery(function($) {
 
 		element.apply
 			.closest('.ui-tabs-panel')
-			.removeClass('in-progress');
+			.removeClass('is-loading is-loading-fadein');
+
 		ui_disabled = false;
 	}
 
@@ -158,7 +160,8 @@ jQuery(function($) {
 
 		element.apply
 			.closest('.ui-tabs-panel')
-			.addClass('in-progress');
+			.addClass('is-loading is-loading-fadein');
+
 		$([element.from[0], element.to[0], element.apply[0]]).prop('disabled', true);
 		$([element.decrement[0], element.zoomout[0], element.increment[0]]).addClass('disabled');
 
@@ -241,7 +244,7 @@ jQuery(function($) {
 					delete request_data.error;
 				}
 				else {
-					updateUrlFromToArguments(json.from, json.to);
+					updateUrlArguments(json.from, json.to);
 					$container
 						.find('.time-input-error')
 						.hide();
@@ -273,25 +276,30 @@ jQuery(function($) {
 	}
 
 	/**
-	 * Replaces 'from' and/or 'to' URL arguments with new values in browser history.
+	 * Update from/to URL arguments and remove page URL argument from browser history.
 	 *
 	 * @param {string} from  Value for 'from' argument.
 	 * @param {string} to    Value for 'to' argument.
 	 */
-	function updateUrlFromToArguments(from, to) {
+	function updateUrlArguments(from, to) {
 		var url = new Curl(),
 			args = url.getArguments();
 
-		if ('from' in args) {
-			url.setArgument('from', from);
-		}
+		if (('from' in args) || ('to' in args) || ('page' in args)) {
+			if ('from' in args) {
+				url.setArgument('from', from);
+			}
 
-		if ('to' in args) {
-			url.setArgument('to', to);
-		}
+			if ('to' in args) {
+				url.setArgument('to', to);
+			}
+
+			if ('page' in args) {
+				url.unsetArgument('page');
+			}
 
-		if (('from' in args) || ('to' in args)) {
 			url.unsetArgument('sid');
+
 			history.replaceState(history.state, '', url.getUrl());
 		}
 	}
@@ -483,7 +491,9 @@ jQuery(function($) {
 		});
 	}
 
-	checkDisableTimeSelectorUI();
+	if (!$container.data('disable-initial-check')) {
+		checkDisableTimeSelectorUI();
+	}
 });
 
 /**
@@ -522,9 +532,7 @@ var timeControl = {
 			src: location.href,
 			dynamic: 1,
 			loadSBox: 0,
-			loadImage: 0,
-			mainObject: 0, // object on changing will reflect on all others
-			onDashboard: 0 // object is on dashboard
+			loadImage: 0
 		}, objData);
 
 		var _this = this;
@@ -552,7 +560,7 @@ var timeControl = {
 
 				// width
 				if ((!isset('width', obj.objDims) || obj.objDims.width < 0) && isset('shiftXleft', obj.objDims) && isset('shiftXright', obj.objDims)) {
-					var width = get_bodywidth();
+					var width = $('.wrapper')[0].scrollWidth - 20;
 
 					if (!is_number(width)) {
 						width = 1000;
@@ -561,7 +569,7 @@ var timeControl = {
 						obj.objDims.width = 0;
 					}
 
-					obj.objDims.width += width - (parseInt(obj.objDims.shiftXleft) + parseInt(obj.objDims.shiftXright) + 23);
+					obj.objDims.width += width - (parseInt(obj.objDims.shiftXleft) + parseInt(obj.objDims.shiftXright)) - 3;
 				}
 
 				// url
@@ -584,7 +592,6 @@ var timeControl = {
 						this.refreshImage(id);
 					}
 				}
-
 			}
 		}
 	},
@@ -610,6 +617,7 @@ var timeControl = {
 			window.flickerfreeScreen.setElementProgressState(obj.id, true);
 			img = jQuery('<img/>', {id: id}).appendTo(('#'+obj.containerid)).on('load', function() {
 				window.flickerfreeScreen.setElementProgressState(obj.id, false);
+				img.closest('.dashbrd-grid-widget').trigger('load.image', {imageid: id});
 			});
 
 			var xhr = (obj.loadSBox == 0)
@@ -650,6 +658,7 @@ var timeControl = {
 				'class': img.attr('class')
 			})
 			.one('load', function() {
+				img.closest('.dashbrd-grid-widget').trigger('load.image', {imageid: img.attr('id')});
 				img.replaceWith(clone);
 				window.flickerfreeScreen.setElementProgressState(obj.id, false);
 			});
@@ -711,6 +720,9 @@ var timeControl = {
 			var url = new Curl(location.href, false);
 			url.unsetArgument('output');
 
+			// Always reset "page" when reloading with updated time range.
+			url.unsetArgument('page');
+
 			location.href = url.getUrl();
 		}
 		else {
