@@ -254,6 +254,9 @@ var jqBlink = {
  */
 var hintBox = {
 
+	preload_hint_timer: null,
+	show_hint_timer: null,
+
 	/**
 	 * Initialize hint box event handlers.
 	 *
@@ -262,51 +265,167 @@ var hintBox = {
 	 */
 	bindEvents: function () {
 		jQuery(document).on('keydown click mouseenter mouseleave', '[data-hintbox=1]', function (e) {
+			var $target = jQuery(this).hasClass('hint-item')
+				? jQuery(this).siblings('.main-hint')
+				: jQuery(this);
 
-			if (jQuery(this).hasClass('hint-item')) {
-				var target = jQuery(this).siblings('.main-hint');
-			}
-			else {
-				var target = jQuery(this);
+			if (e.type === 'keydown') {
+				if (e.which != 13) {
+					return;
+				}
+
+				var offset = $target.offset(),
+					w = jQuery(window);
+
+				// Emulate a click on the left middle point of the target.
+				e.clientX = offset.left - w.scrollLeft();
+				e.clientY = offset.top - w.scrollTop() + ($target.height() / 2);
+				e.preventDefault();
 			}
 
-			switch (e.type) {
-				case 'mouseenter':
-					hintBox.showHint(e, target[0], target.next('.hint-box').html(), target.data('hintbox-class'), false,
-						target.data('hintbox-style')
-					);
-					break;
+			if ($target.data('hintbox-preload') && $target.next('.hint-box').children().length == 0) {
+				clearTimeout(hintBox.preload_hint_timer);
 
-				case 'mouseleave':
-					hintBox.hideHint(target[0], false);
-					break;
+				// Manually trigger preloaderCloseHandler for the previous preloader.
+				if (jQuery('#hintbox-preloader').length) {
 
-				case 'keydown':
-					if (e.which == 13 && target.data('hintbox-static') == 1) {
-						var offset = target.offset(),
-							w = jQuery(window);
-						// Emulate click on left middle point of link.
-						e.clientX = offset.left - w.scrollLeft();
-						e.clientY = offset.top - w.scrollTop() + (target.height() / 2);
-						e.preventDefault();
-
-						hintBox.showStaticHint(e, target[0], target.data('hintbox-class'), false,
-							target.data('hintbox-style')
-						);
+					// Prevent loading restart on repetitive click and keydown events.
+					if (e.type === 'click' || e.type === 'keydown') {
+						return false;
 					}
-					break;
 
-				case 'click':
-					if (target.data('hintbox-static') == 1) {
-						hintBox.showStaticHint(e, target[0], target.data('hintbox-class'), false,
-							target.data('hintbox-style')
-						);
-					}
-					break;
+					jQuery(document).trigger('click');
+				}
+
+				if (e.type === 'mouseleave') {
+					$target.blur();
+
+					return false;
+				}
+
+				var preloadHintHandler = function() {
+					hintBox.preloadHint(e, $target);
+				}
+
+				if (e.type === 'mouseenter') {
+					hintBox.preload_hint_timer = setTimeout(preloadHintHandler, 400);
+				}
+				else {
+					preloadHintHandler();
+				}
+
+				return false;
 			}
+
+			hintBox.displayHint(e, $target, 400);
+
+			return false;
 		});
 	},
 
+	displayHint: function(e, $target, delay = 0) {
+		clearTimeout(hintBox.show_hint_timer);
+
+		switch (e.handleObj.origType) {
+			case 'mouseenter':
+				var showHintHandler = function() {
+					hintBox.showHint(e, $target[0], $target.next('.hint-box').html(), $target.data('hintbox-class'),
+						false, $target.data('hintbox-style')
+					);
+				}
+
+				if (delay > 0) {
+					hintBox.show_hint_timer = setTimeout(showHintHandler, delay);
+				}
+				else {
+					showHintHandler();
+				}
+				break;
+
+			case 'mouseleave':
+				hintBox.hideHint($target[0], false);
+				$target.blur();
+				break;
+
+			case 'keydown':
+			case 'click':
+				if ($target.data('hintbox-static') == 1) {
+					hintBox.showStaticHint(e, $target[0], $target.data('hintbox-class'), false,
+						$target.data('hintbox-style')
+					);
+				}
+				break;
+		}
+	},
+
+	preloadHint: function(e, $target) {
+		var url = new Curl('zabbix.php'),
+			data = $target.data('hintbox-preload');
+
+		url.setArgument('action', 'hint.box');
+		url.setArgument('type', data.type);
+
+		var xhr = jQuery.ajax({
+			url: url.getUrl(),
+			method: 'POST',
+			data: {
+				data: data.data
+			},
+			dataType: 'json'
+		});
+
+		var $preloader = hintBox.createPreloader();
+
+		var preloader_timer = setTimeout(function() {
+			$preloader.fadeIn(200);
+			hintBox.positionElement(e, $target[0], $preloader);
+		}, 500);
+
+		addToOverlaysStack($preloader.prop('id'), $target[0], 'preloader', xhr);
+
+		xhr.done(function(resp) {
+			clearTimeout(preloader_timer);
+			overlayPreloaderDestroy($preloader.prop('id'));
+
+			var $hint_box = $target.next('.hint-box').empty();
+
+			if (resp.messages) {
+				$hint_box.append(resp.messages);
+			}
+			if (resp.data) {
+				$hint_box.append(resp.data);
+			}
+
+			hintBox.displayHint(e, $target);
+		});
+
+		jQuery(document)
+			.off('click', hintBox.preloaderCloseHandler)
+			.on('click', {id: $preloader.prop('id')}, hintBox.preloaderCloseHandler);
+	},
+
+	/**
+	 * Create preloader elements for the hint box.
+	 */
+	createPreloader: function() {
+		return jQuery('<div>', {
+			'id': 'hintbox-preloader',
+			'class': 'is-loading hintbox-preloader'
+		})
+			.appendTo($('.wrapper'))
+			.on('click', function(e) {
+				e.stopPropagation();
+			})
+			.hide();
+	},
+
+	/**
+	 * Event handler for the preloader elements destroy.
+	 */
+	preloaderCloseHandler: function(event) {
+		overlayPreloaderDestroy(event.data.id);
+	},
+
 	createBox: function(e, target, hintText, className, isStatic, styles, appendTo) {
 		var hintboxid = hintBox.getUniqueId(),
 			box = jQuery('<div></div>', {'data-hintboxid': hintboxid}).addClass('overlay-dialogue'),
@@ -381,7 +500,7 @@ var hintBox = {
 
 			if (resizeAfterLoad) {
 				hintText.one('load', function(e) {
-					hintBox.positionHint(e, target);
+					hintBox.positionElement(e, target, target.hintBoxItem);
 				});
 			}
 		}
@@ -393,7 +512,7 @@ var hintBox = {
 		}
 
 		target.hintBoxItem = hintBox.createBox(e, target, hintText, className, isStatic, styles);
-		hintBox.positionHint(e, target);
+		hintBox.positionElement(e, target, target.hintBoxItem);
 		target.hintBoxItem.show();
 
 		if (target.isStatic) {
@@ -402,13 +521,13 @@ var hintBox = {
 		}
 	},
 
-	positionHint: function(e, target) {
+	positionElement: function(e, target, $elem) {
 		if (e.clientX) {
 			target.clientX = e.clientX;
 			target.clientY = e.clientY;
 		}
 
-		var $host = target.hintBoxItem.offsetParent(),
+		var $host = $elem.offsetParent(),
 			host_offset = $host.offset(),
 			// Usable area relative to host.
 			host_x_min = $host.scrollLeft(),
@@ -424,15 +543,15 @@ var hintBox = {
 			event_y = target.clientY - host_offset.top + $host.scrollTop(),
 			event_offset = 10,
 			// Hint box width and height.
-			hint_width = target.hintBoxItem.outerWidth(),
-			hint_height = target.hintBoxItem.outerHeight(),
+			hint_width = $elem.outerWidth(),
+			hint_height = $elem.outerHeight(),
 			/*
 				Fix popup width and height since browsers will tend to reduce the size of the popup, if positioned further
 				than the width of window when horizontal scrolling is active.
 			*/
 			css = {
-				width: target.hintBoxItem.width(),
-				height: target.hintBoxItem.height()
+				width: $elem.width(),
+				height: $elem.height()
 			};
 
 		if (event_x + event_offset + hint_width <= host_x_max) {
@@ -461,7 +580,7 @@ var hintBox = {
 			}
 		}
 
-		target.hintBoxItem.css(css);
+		$elem.css(css);
 	},
 
 	hideHint: function(target, hideStatic) {
