@@ -1,6 +1,6 @@
 /*
 ** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2021 Zabbix SIA
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -19,23 +19,14 @@
 
 
 jQuery(function($) {
-	var ZBX_STYLE_CLASS = 'multiselect-control',
-		KEY = {
-			ARROW_DOWN: 40,
-			ARROW_LEFT: 37,
-			ARROW_RIGHT: 39,
-			ARROW_UP: 38,
-			BACKSPACE: 8,
-			DELETE: 46,
-			ENTER: 13,
-			ESCAPE: 27,
-			TAB: 9
-		};
+	var ZBX_STYLE_CLASS = 'multiselect-control';
+	const MS_ACTION_POPUP = 0;
+	const MS_ACTION_AUTOSUGGEST = 1;
 
 	/**
 	 * Multi select helper.
 	 *
-	 * @param string options['objectName']		backend data source
+	 * @param string options['object_name']		backend data source
 	 * @param object options['objectOptions']	parameters to be added the request URL (optional)
 	 *
 	 * @see jQuery.multiSelect()
@@ -46,7 +37,7 @@ jQuery(function($) {
 		var curl = new Curl('jsrpc.php', false);
 		curl.setArgument('type', 11); // PAGE_TYPE_TEXT_RETURN_JSON
 		curl.setArgument('method', 'multiselect.get');
-		curl.setArgument('objectName', options.objectName);
+		curl.setArgument('object_name', options.object_name);
 
 		for (var key in options.objectOptions) {
 			curl.setArgument(key, options.objectOptions[key]);
@@ -83,21 +74,36 @@ jQuery(function($) {
 				});
 			}
 
+			// Sort entries by name field.
+			data.sort(function(a, b) {
+				if (a.name === b.name) {
+					return 0;
+				}
+				else {
+					return (a.name < b.name) ? -1 : 1;
+				}
+			});
+
 			return data;
 		},
 
 		/**
 		 * Insert outside data
 		 *
-		 * @param object    multiselect value object
+		 * @param {array} items           Multiselect value object.
+		 * @param {bool}  trigger_change  (optional) Either to trigger element on-change event once data added. True by default.
 		 *
 		 * @return jQuery
 		 */
-		addData: function(items) {
+		addData: function(items, trigger_change) {
 			return this.each(function() {
 				var $obj = $(this),
 					ms = $obj.data('multiSelect');
 
+				if (typeof trigger_change !== 'boolean') {
+					trigger_change = true;
+				}
+
 				if (ms.options.selectedLimit == 1) {
 					for (var id in ms.values.selected) {
 						removeSelected($obj, id);
@@ -108,7 +114,7 @@ jQuery(function($) {
 					addSelected($obj, items[i]);
 				}
 
-				$obj.trigger('change', ms);
+				trigger_change && $obj.trigger('change', ms);
 			});
 		},
 
@@ -263,8 +269,12 @@ jQuery(function($) {
 	 * @param int    options['limit']				how many available items can be received from backend (optional)
 	 * @param object options['popup']				popup data {parameters, width, height} (optional)
 	 * @param string options['popup']['parameters']
+	 * @param string options['popup']['filter_preselect_fields']
 	 * @param int    options['popup']['width']
 	 * @param int    options['popup']['height']
+	 * @param object options['autosuggest']         autosuggest options (optional)
+	 * @param object options['autosuggest']['filter_preselect_fields'] autosuggest preselect fields (optional)
+	 * @param string options['autosuggest']['filter_preselect_fields']['hosts'] autosuggest host preselect field (optional)
 	 * @param string options['styles']				additional style for multiselect wrapper HTML element (optional)
 	 * @param string options['styles']['property']
 	 * @param string options['styles']['value']
@@ -338,12 +348,6 @@ jQuery(function($) {
 				return false;
 			});
 
-			if (IE) {
-				ms.values.available_div.on('mousedown', function() {
-					ms.values.available_false_click = true;
-				});
-			}
-
 			$obj.data('multiSelect', ms);
 
 			$obj.wrap($('<div>', {
@@ -371,11 +375,19 @@ jQuery(function($) {
 			}
 
 			$obj
-				.on('mousedown', function() {
+				.on('mousedown', function(event) {
 					if (isSearchFieldVisible($obj) && ms.options.selectedLimit != 1) {
 						$obj.addClass('active');
 						$('.selected li.selected', $obj).removeClass('selected');
+
+						// Focus input only when not clicked on selected item.
+						if (!$(event.target).parents('.multiselect-list').length) {
+							$('input[type="text"]', $obj).focus();
+						}
 					}
+				})
+				.on('remove', function() {
+					cleanSearch($obj);
 				});
 
 			if (empty(ms.options.data)) {
@@ -403,9 +415,19 @@ jQuery(function($) {
 				}
 
 				popup_button.on('click', function(event) {
+					var popup_options = ms.options.popup.parameters;
+
+					if (ms.options.popup.filter_preselect_fields) {
+						popup_options = jQuery.extend(popup_options, getFilterPreselectField($obj, MS_ACTION_POPUP));
+					}
+
+					if (typeof popup_options['disable_selected'] !== 'undefined' && popup_options['disable_selected']) {
+						popup_options['disableids'] = Object.keys(ms.values.selected);
+					}
+
 					// Click used instead focus because in patternselect listen only click.
 					$('input[type="text"]', $obj).click();
-					return PopUp('popup.generic', ms.options.popup.parameters, null, event.target);
+					return PopUp('popup.generic', popup_options, null, event.target);
 				});
 
 				$obj.after($('<div>', {'class': 'multiselect-button'}).append(popup_button));
@@ -413,6 +435,40 @@ jQuery(function($) {
 		});
 	};
 
+	/**
+	 * Get current value from preselect filter field.
+	 *
+	 * @param {jQuery} $obj    Multiselect instance.
+	 * @param {int}    action  User action that caused preselection.
+	 *
+	 * @return {object}
+	 */
+	function getFilterPreselectField($obj, action) {
+		var ms = $obj.data('multiSelect'),
+			preselect_options = ms.options[(action == MS_ACTION_AUTOSUGGEST) ? 'autosuggest' : 'popup'] || null,
+			ret = {};
+
+		if (!preselect_options) {
+			return ret;
+		}
+
+		if (typeof preselect_options.filter_preselect_fields.hosts !== 'undefined') {
+			var hosts = $('#' + preselect_options.filter_preselect_fields.hosts).multiSelect('getData');
+			if (hosts.length != 0) {
+				ret.hostid = hosts[0].id;
+			}
+		}
+
+		if (typeof preselect_options.filter_preselect_fields.hostgroups !== 'undefined') {
+			var host_groups = $('#' + preselect_options.filter_preselect_fields.hostgroups).multiSelect('getData');
+			if (host_groups.length != 0) {
+				ret.groupid = host_groups[0].id;
+			}
+		}
+
+		return ret;
+	}
+
 	function makeMultiSelectInput($obj) {
 		var ms = $obj.data('multiSelect'),
 			$label = $('label[for=' + $obj.attr('id') + '_ms]'),
@@ -428,11 +484,11 @@ jQuery(function($) {
 			})
 				.on('keyup', function(e) {
 					switch (e.which) {
-						case KEY.ARROW_DOWN:
-						case KEY.ARROW_LEFT:
-						case KEY.ARROW_RIGHT:
-						case KEY.ARROW_UP:
-						case KEY.ESCAPE:
+						case KEY_ARROW_DOWN:
+						case KEY_ARROW_LEFT:
+						case KEY_ARROW_RIGHT:
+						case KEY_ARROW_UP:
+						case KEY_ESCAPE:
 							return false;
 					}
 
@@ -452,6 +508,9 @@ jQuery(function($) {
 					}
 
 					if (search !== '') {
+						var preselect_values = getFilterPreselectField($obj, MS_ACTION_AUTOSUGGEST),
+							cache_key = search + JSON.stringify(preselect_values);
+
 						/*
 						 * Strategy:
 						 * 1. Load the cached result set if such exists for the given term and show the list.
@@ -459,36 +518,38 @@ jQuery(function($) {
 						 * 3. Schedule result set retrieval for the given term otherwise.
 						 */
 
-						if (search in ms.values.searches) {
+						if (cache_key in ms.values.searches) {
 							ms.values.search = search;
+							ms.values.cache_key = cache_key;
 							loadAvailable($obj);
 							showAvailable($obj);
 						}
-						else if (!(search in ms.values.searching)) {
+						else if (!(cache_key in ms.values.searching)) {
 							ms.values.searchTimeout = setTimeout(function() {
-								ms.values.searching[search] = true;
+								ms.values.searching[cache_key] = true;
 
 								$.ajax({
 									url: ms.options.url + '&curtime=' + new CDate().getTime(),
 									type: 'GET',
 									dataType: 'json',
 									cache: false,
-									data: {
+									data: jQuery.extend({
 										search: search,
-										limit: getLimit($obj)
-									}
+										limit: getLimit($obj),
+									}, preselect_values)
 								})
 									.then(function(response) {
-										ms.values.searches[search] = response.result;
+										ms.values.searches[cache_key] = response.result;
 
 										if (search === $input.val().trim()) {
 											ms.values.search = search;
+											ms.values.cache_key = cache_key;
 											loadAvailable($obj);
 											showAvailable($obj);
 										}
 									})
 									.done(function() {
-										delete ms.values.searching[search];
+										delete ms.values.searching[cache_key];
 									});
 
 								delete ms.values.searchTimeout;
@@ -501,13 +562,13 @@ jQuery(function($) {
 				})
 				.on('keydown', function(e) {
 					switch (e.which) {
-						case KEY.TAB:
-						case KEY.ESCAPE:
+						case KEY_TAB:
+						case KEY_ESCAPE:
 							hideAvailable($obj);
 							cleanSearchInput($obj);
 							break;
 
-						case KEY.ENTER:
+						case KEY_ENTER:
 							if ($input.val() !== '') {
 								var $selected = $('li.suggest-hover', ms.values.available_div);
 
@@ -520,7 +581,7 @@ jQuery(function($) {
 							}
 							break;
 
-						case KEY.ARROW_LEFT:
+						case KEY_ARROW_LEFT:
 							if ($input.val() === '') {
 								var $collection = $('.selected li', $obj);
 
@@ -536,7 +597,7 @@ jQuery(function($) {
 							}
 							break;
 
-						case KEY.ARROW_RIGHT:
+						case KEY_ARROW_RIGHT:
 							if ($input.val() === '') {
 								var $collection = $('.selected li', $obj);
 
@@ -552,13 +613,13 @@ jQuery(function($) {
 							}
 							break;
 
-						case KEY.ARROW_UP:
-						case KEY.ARROW_DOWN:
+						case KEY_ARROW_UP:
+						case KEY_ARROW_DOWN:
 							var $collection = $('li', ms.values.available_div.filter(':visible')),
 								$selected = $collection.filter('.suggest-hover').removeClass('suggest-hover');
 
 							if ($selected.length) {
-								$selected = (e.which == KEY.ARROW_UP)
+								$selected = (e.which == KEY_ARROW_UP)
 									? ($selected.is(':first-child') ? $collection.last() : $selected.prev())
 									: ($selected.is(':last-child') ? $collection.first() : $selected.next());
 
@@ -570,8 +631,8 @@ jQuery(function($) {
 
 							return false;
 
-						case KEY.BACKSPACE:
-						case KEY.DELETE:
+						case KEY_BACKSPACE:
+						case KEY_DELETE:
 							if ($input.val() === '') {
 								var $selected = $('.selected li.selected', $obj);
 
@@ -582,7 +643,7 @@ jQuery(function($) {
 									if (typeof item.disabled === 'undefined' || !item.disabled) {
 										var aria_text = sprintf(t('Removed, %1$s'), $selected.data('label'));
 
-										$selected = (e.which == KEY.BACKSPACE)
+										$selected = (e.which == KEY_BACKSPACE)
 											? ($selected.is(':first-child') ? $selected.next() : $selected.prev())
 											: ($selected.is(':last-child') ? $selected.prev() : $selected.next());
 
@@ -610,7 +671,7 @@ jQuery(function($) {
 										$aria_live.text(t('Can not be removed'));
 									}
 								}
-								else if (e.which == KEY.BACKSPACE) {
+								else if (e.which == KEY_BACKSPACE) {
 									/*
 									 * Pressing Backspace on empty input field should select last element in
 									 * multiselect. For next Backspace press to be able to remove it.
@@ -723,6 +784,9 @@ jQuery(function($) {
 					if (isSearchFieldVisible($obj) && ms.options.selectedLimit != 1) {
 						$('.selected li.selected', $obj).removeClass('selected');
 						$(this).addClass('selected');
+
+						// preventScroll not work in IE.
+						$('input[type="text"]', $obj)[0].focus({preventScroll: true});
 					}
 				});
 
@@ -795,7 +859,7 @@ jQuery(function($) {
 
 	function loadAvailable($obj) {
 		var ms = $obj.data('multiSelect'),
-			data = ms.values.searches[ms.values.search];
+			data = ms.values.searches[ms.values.cache_key];
 
 		cleanAvailable($obj);
 
@@ -1065,6 +1129,7 @@ jQuery(function($) {
 	function cleanSearchHistory($obj) {
 		var ms = $obj.data('multiSelect');
 
+		ms.values.cache_key = '';
 		ms.values.search = '';
 		ms.values.searches = {};
 		ms.values.searching = {};
@@ -1119,7 +1184,7 @@ jQuery(function($) {
 	}
 
 	function isSearchFieldVisible($obj) {
-		return !$obj.hasClass('.search-disabled');
+		return !$obj.hasClass('search-disabled');
 	}
 
 	function getLimit($obj) {
